OC.L10N.register(
    "spreed",
    {
    "a conversation" : "размова",
    "(Duration %s)" : "(Працягласць %s)",
    "_%n guest_::_%n guests_" : ["%n госць","%n госці","%n гасцей","%n гасцей"],
    "_%n other_::_%n others_" : ["яшчэ %n","яшчэ %n","яшчэ %n","яшчэ %n"],
    "{actor} invited you to {call}" : "{actor} запрасіў(-ла) вас у {call}",
    "Other activities" : "Іншая актыўнасць",
    "Talk" : "Talk",
    "Guest" : "Госць",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Вітаем у Nextcloud Talk!\nУ гэтай размове вы даведаецеся пра новыя функцыі, даступныя ў Nextcloud Talk.",
    "## New in Talk %s" : "## Новае ў Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Цяпер можна выкарыстоўваць Microsoft Edge і Safari для ўдзелу ў аўдыя- і відэазванках",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Цяпер вы можаце апавясціць усіх удзельнікаў, напісаўшы ў чат \"@all\"",
    "- You can now mention guests in the chat" : "- Цяпер вы можаце згадваць у чаце гасцей",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Цяпер вы можаце запампоўваць і перацягваць файлы непасрэдна са сваёй прылады ў чат",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Цяпер вы можаце шукаць чаты і паведамленні ва ўніфікаваным пошуку ў верхняй панэлі",
    "- You can now change your camera and microphone while being in a call" : "- Цяпер вы можаце змяняць камеру і мікрафон падчас выкліку",
    "- Raise your hand in a call with the R key" : "- Падніміце руку падчас размовы з дапамогай клавішы R",
    "- You can now blur your background in the newly designed call view" : "- Цяпер вы можаце размываць фон у новым дызайне выкліку",
    "- Moderators can now assign general and individual permissions to participants" : "- Мадэратары цяпер могуць прызначаць удзельнікам агульныя і індывідуальныя дазволы",
    "- You can now react to chat messages" : "- Цяпер вы можаце рэагаваць на паведамленні ў чаце",
    "- Configure an expiration time for chat messages" : "- Наладжвайце тэрмін дзеяння паведамленняў у чаце",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Мадэратары зараз могуць ствараць групавыя пакоі (патрабуе высокапрадукцыйнага бэкэнду)",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Акрамя размытасці фону ў відэавыкліках, цяпер даступныя віртуальныя фоны.",
    "- Reactions are now available during calls" : "- Падчас выклікаў цяпер даступныя рэакцыі",
    "- Groups can now be mentioned in chats" : "- Цяпер у чатах можна згадваць групы",
    "- **Markdown** can now be used in _chat_ messages" : "- У паведамленнях _чата_ цяпер можна выкарыстоўваць **Markdown**",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Выкарыстоўвайце размову **Асабістыя нататкі**, каб рабіць нататкі і абменьвацца інфармацыяй паміж вашымі прыладамі",
    "- Unsent message drafts are now saved in your browser" : "- Чарнавікі неадпраўленых паведамленняў цяпер захоўваюцца ў браўзеры",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Цяпер у размовах адлюстроўваюцца будучыя званкі з прывязаных падзей календара і замены пры адсутнасці.",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Вітайце кліент Nextcloud Talk для працоўнага стала для Windows, macOS і Linux: %s",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Шукайце паведамленні ў бягучай размове непасрэдна ў правай бакавой панэлі",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- З дапамогай новага кампактнага спісу (уключыце ў наладах Talk) вы адразу бачыце больш размоў",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Размовы пра сустрэчы цяпер сінхранізуюць загаловак і апісанне з календара і хаваюцца з дапамогай фільтра пошуку, пакуль не наблізіцца час іх пачатку.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Пазначайце размовы як сакрэтныя ў наладах апавяшчэнняў, каб схаваць змест паведамленняў са спісу размоў і апавяшчэнняў",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Каб атрымліваць push-апавяшчэнні ў рэжыме \"Не турбаваць\", пазначайце размовы як важныя",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Дадайце іншых удзельнікаў да індывідуальнага выкліку, каб адразу стварыць новы групавы выклік",
    "- Use threads to keep your chat and discussions organized" : "- Арганізоўвайце чаты і абмеркаванні з дапамогай гутарак",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Цяпер падчас выкліку даступна імгненная транскрыпцыя (патрабуецца праграма ExApp для імгненнай транскрыпцыі і высокапрадукцыйны бэкенд)",
    "- Moderators can now pin messages so they are kept at the top" : "- Цяпер мадэратары могуць замацоўваць паведамленні, якія будуць заўсёды ўверсе старонкі",
    "- Schedule a message to send it at a later time" : "- Заплануйце адпраўку паведамлення на пазнейшы час",
    "Talk updates ✅" : "Абнаўленні Talk ✅",
    "Reaction deleted by author" : "Рэакцыя выдалена аўтарам",
    "{actor} created the conversation" : "{actor} стварыў(-ла) размову",
    "You created the conversation" : "Вы стварылі размову",
    "System created the conversation" : "Сістэма стварыла размову",
    "An administrator created the conversation" : "Адміністратар стварыў размову",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} перайменаваў(-ла) размову з  \"%1$s\" на \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Вы перайменавалі размову з  \"%1$s\" на \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Адміністратар перайменаваў размову з \"%1$s\" на \"%2$s\"",
    "{actor} set the description" : "{actor} задаў(-ла) апісанне",
    "You set the description" : "Вы задалі апісанне",
    "An administrator set the description" : "Адміністратар задаў апісанне",
    "{actor} removed the description" : "{actor} выдаліў(-ла) апісанне",
    "You removed the description" : "Вы выдалілі апісанне",
    "An administrator removed the description" : "Адміністратар выдаліў апісанне",
    "You started a silent call" : "Вы пачалі бязгучны выклік",
    "Outgoing silent call" : "Выходны бязгучны выклік",
    "{actor} started a silent call" : "{actor} пачаў(-ла) бязгучны выклік",
    "Incoming silent call" : "Уваходны бязгучны выклік",
    "You started a call" : "Вы пачалі выклік",
    "Outgoing call" : "Выходны выклік",
    "{actor} started a call" : "{actor} пачаў(-ла) выклік",
    "Incoming call" : "Уваходны выклік",
    "{actor} joined the call" : "{actor} далучыўся(-лася) да выкліку ",
    "You joined the call" : "Вы далучыліся да выкліку",
    "{actor} left the call" : "{actor} выйшаў(-ла) з выкліку",
    "You left the call" : "Вы выйшлі з выкліку",
    "{actor} unlocked the conversation" : "{actor} разблакіраваў(-ла) размову",
    "You unlocked the conversation" : "Вы разблакіравалі размову",
    "An administrator unlocked the conversation" : "Адміністратар разблакіраваў размову",
    "{actor} locked the conversation" : "{actor} заблакіраваў(-ла) размову",
    "You locked the conversation" : "Вы заблакіравалі размову",
    "An administrator locked the conversation" : "Адміністратар заблакіраваў размову",
    "{actor} opened the conversation to registered users" : "{actor} адкрыў(-ла) размову для зарэгістраваных карыстальнікаў",
    "You opened the conversation to registered users" : "Вы адкрылі размову для зарэгістраваных карыстальнікаў",
    "An administrator opened the conversation to registered users" : "Адміністратар адкрыў размову для зарэгістраваных карыстальнікаў",
    "The conversation is now open to everyone" : "Размова адкрыта для ўсіх",
    "{actor} opened the conversation to everyone" : "{actor} адкрыў(-ла) размову для ўсіх",
    "You opened the conversation to everyone" : "Вы адкрылі размову для ўсіх",
    "{actor} started breakout rooms" : "{actor} пачаў(-ла) групавыя пакоі",
    "You started breakout rooms" : "Вы пачалі групавыя пакоі",
    "{actor} stopped breakout rooms" : "{actor} спыніў(-ла) групавыя пакоі",
    "You stopped breakout rooms" : "Вы спынілі групавыя пакоі",
    "{actor} allowed guests" : "{actor} дазволіў(-ла) гасцей",
    "You allowed guests" : "Вы дазволілі гасцей",
    "An administrator allowed guests" : "Адміністратар дазволіў гасцей",
    "{actor} disallowed guests" : "{actor} забараніў(-ла) гасцей",
    "You disallowed guests" : "Вы забаранілі гасцей",
    "An administrator disallowed guests" : "Адміністратар забараніў гасцей",
    "{actor} set a password" : "{actor} задаў(-ла) пароль",
    "You set a password" : "Вы задалі пароль",
    "An administrator set a password" : "Адміністратар задаў пароль",
    "{actor} removed the password" : "{actor} выдаліў(-ла) пароль",
    "You removed the password" : "Вы выдалілі пароль",
    "An administrator removed the password" : "Адміністратар выдаліў пароль",
    "{actor} added {user}" : "{actor} дадаў(-ла) {user}",
    "You joined the conversation" : "Вы далучыліся да размовы",
    "{actor} joined the conversation" : "{actor} далучыўся(-лася) да размовы",
    "You added {user}" : "Вы дадалі {user}",
    "{actor} added you" : "{actor} дадаў(-ла) вас",
    "An administrator added you" : "Адміністратар дадаў вас",
    "An administrator added {user}" : "Адміністратар дадаў {user}",
    "You left the conversation" : "Вы выйшлі з размовы",
    "{actor} left the conversation" : "{actor} выйшаў(-ла) з размовы",
    "{actor} removed {user}" : "{actor} выдаліў(-ла) {user}",
    "You removed {user}" : "Вы выдалілі {user}",
    "{actor} removed you" : "{actor} выдаліў(-ла) вас",
    "An administrator removed you" : "Адміністратар выдаліў вас",
    "An administrator removed {user}" : "Адміністратар выдаліў {user}",
    "{actor} invited {federated_user}" : "{actor} запрасіў(-ла) {federated_user}",
    "You invited {federated_user}" : "Вы запрасілі {federated_user}",
    "You accepted the invitation" : "Вы прынялі запрашэнне",
    "{actor} invited you" : "{actor} запрасіў(-ла) вас",
    "An administrator invited you" : "Адміністратар запрасіў вас",
    "An administrator invited {federated_user}" : "Адміністратар запрасіў {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} прыняў(-ла) запрашэнне",
    "{actor} removed {federated_user}" : "{actor} выдаліў(-ла) {federated_user}",
    "You removed {federated_user}" : "Вы выдалілі {federated_user}",
    "You declined the invitation" : "Вы адхілілі запрашэнне",
    "An administrator removed {federated_user}" : "Адміністратар выдаліў {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} адхіліў(-ла) запрашэнне",
    "{actor} added group {group}" : "{actor} дадаў(-ла) групу {group}",
    "You added group {group}" : "Вы дадалі групу {group}",
    "An administrator added group {group}" : "Адміністратар дадаў групу {group}",
    "{actor} removed group {group}" : "{actor} выдаліў(-ла) групу {group}",
    "You removed group {group}" : "Вы выдалілі групу {group}",
    "An administrator removed group {group}" : "Адміністратар выдаліў групу {group}",
    "{actor} added team {circle}" : "{actor} дадаў(-ла) каманду {circle}",
    "You added team {circle}" : "Вы дадалі каманду {circle}",
    "An administrator added team {circle}" : "Адміністратар дадаў каманду {circle}",
    "{actor} removed team {circle}" : "{actor} выдаліў(-ла) каманду {circle}",
    "You removed team {circle}" : "Вы выдалілі каманду {circle}",
    "An administrator removed team {circle}" : "Адміністратар выдаліў каманду {circle}",
    "{actor} added {phone}" : "{actor} дадаў(-ла) {phone}",
    "You added {phone}" : "Вы дадалі {phone}",
    "An administrator added {phone}" : "Адміністратар дадаў {phone}",
    "{actor} removed {phone}" : "{actor} выдаліў(-ла) {phone}",
    "You removed {phone}" : "Вы выдалілі {phone}",
    "An administrator removed {phone}" : "Адміністратар выдаліў {phone}",
    "{actor} promoted {user} to moderator" : "{actor} прызначыў(-ла) {user} мадэратарам",
    "You promoted {user} to moderator" : "Вы прызначылі {user} мадэратарам",
    "{actor} promoted you to moderator" : "{actor} прызначыў(-ла) вас мадэратарам",
    "An administrator promoted you to moderator" : "Адміністратар прызначыў вас мадэратарам",
    "An administrator promoted {user} to moderator" : "Адміністратар прызначыў {user} мадэратарам",
    "{actor} demoted {user} from moderator" : "{actor} пазбавіў(-ла) {user} правоў мадэратара",
    "You demoted {user} from moderator" : "Вы пазбавілі {user} правоў мадэратара",
    "{actor} demoted you from moderator" : "{actor} пазбавіў(-ла) вас правоў мадэратара",
    "An administrator demoted you from moderator" : "Адміністратар пазбавіў вас правоў мадэратара",
    "An administrator demoted {user} from moderator" : "Адміністратар пазбавіў {user} правоў мадэратара",
    "{actor} shared a file which is no longer available" : "{actor} абагуліў(-ла) файл, які больш недаступны",
    "You shared a file which is no longer available" : "Вы абагулілі файл, які больш недаступны",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} наладзіў(-ла) Matterbridge для сінхранізацыі гэтай размовы з іншымі чатамі",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Вы наладзілі Matterbridge для сінхранізацыі гэтай размовы з іншымі чатамі",
    "{actor} created thread {title}" : "{actor} стварыў(-ла) гутарку {title}",
    "You created thread {title}" : "Вы стварылі гутарку {title}",
    "{actor} renamed thread {title}" : "{actor} перайменаваў(-ла) гутарку {title}",
    "You renamed thread {title}" : "Вы перайменавалі гутарку {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} абнавіў(-ла) канфігурацыю Matterbridge",
    "You updated the Matterbridge configuration" : "Вы абнавілі канфігурацыю Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} выдаліў(-ла) канфігурацыю Matterbridge",
    "You removed the Matterbridge configuration" : "Вы выдалілі канфігурацыю Matterbridge",
    "{actor} started Matterbridge" : "{actor} запусціў(-ла) Matterbridge",
    "You started Matterbridge" : "Вы запусцілі Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} спыніў(-ла) Matterbridge",
    "You stopped Matterbridge" : "Вы спынілі Matterbridge",
    "{actor} deleted a message" : "{actor} выдаліў(-ла) паведамленне",
    "You deleted a message" : "Вы выдалілі паведамленне",
    "{actor} edited a message" : "{actor} адрэдагаваў(-ла) паведамленне",
    "You edited a message" : "Вы адрэдагавалі паведамленне",
    "{actor} pinned a message" : "{actor} замацаваў(-ла) паведамленне",
    "You pinned a message" : "Вы замацавалі паведамленне",
    "{actor} unpinned a message" : "{actor} адмацаваў(-ла) паведамленне",
    "Message was automatically unpinned" : "Паведамленне было аўтаматычна адмацавана",
    "You unpinned a message" : "Вы адмацавалі паведамленне",
    "{actor} deleted a reaction" : "{actor} выдаліў(-ла) рэакцыю",
    "You deleted a reaction" : "Вы выдалілі рэакцыю",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Вы задалі тэрмін дзеяння паведамленняў на %n тыдзень","Вы задалі тэрмін дзеяння паведамленняў на %n тыдні","Вы задалі тэрмін дзеяння паведамленняў на %n тыдняў","Вы задалі тэрмін дзеяння паведамленняў на %n тыдняў"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Вы задалі тэрмін дзеяння паведамленняў на %n дзень","Вы задалі тэрмін дзеяння паведамленняў на %n дні","Вы задалі тэрмін дзеяння паведамленняў на %n дзён","Вы задалі тэрмін дзеяння паведамленняў на %n дзён"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Вы задалі тэрмін дзеяння паведамленняў на %n гадзіну","Вы задалі тэрмін дзеяння паведамленняў на %n гадзіны","Вы задалі тэрмін дзеяння паведамленняў на %n гадзін","Вы задалі тэрмін дзеяння паведамленняў на %n гадзін"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Вы задалі тэрмін дзеяння паведамленняў на %n хвіліну","Вы задалі тэрмін дзеяння паведамленняў на %n хвіліны","Вы задалі тэрмін дзеяння паведамленняў на %n хвілін","Вы задалі тэрмін дзеяння паведамленняў на %n хвілін"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n тыдзень","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n тыдні","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n тыдняў","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n тыдняў"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n дзень","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n дні","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n дзён","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n дзён"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n гадзіну","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n гадзіны","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n гадзін","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n гадзін"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n хвіліну","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n хвіліны","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n хвілін","{actor} задаў(-ла) тэрмін дзеяння паведамленняў на %n хвілін"],
    "{actor} disabled message expiration" : "{actor} адключыў(-ла) тэрмін дзеяння паведамленняў",
    "You disabled message expiration" : "Вы адключылі тэрмін дзеяння паведамленняў",
    "{actor} cleared the history of the conversation" : "{actor} ачысціў(-ла) гісторыю размовы",
    "You cleared the history of the conversation" : "Вы ачысцілі гісторыю размовы",
    "{actor} set the conversation picture" : "{actor} задаў(-ла) аватар размовы",
    "You set the conversation picture" : "Вы задалі аватар размовы",
    "{actor} removed the conversation picture" : "{actor} выдаліў(-ла) аватар размовы",
    "You removed the conversation picture" : "Вы выдалілі аватар размовы",
    "{actor} ended the poll {poll}" : "{actor} завяршыў(-ла) апытанне {poll}",
    "You ended the poll {poll}" : "Вы завяршылі апытанне {poll}",
    "{actor} started the video recording" : "{actor} пачаў(-ла) відэазапіс",
    "You started the video recording" : "Вы пачалі відэазапіс",
    "{actor} stopped the video recording" : "{actor} спыніў(-ла) відэазапіс",
    "You stopped the video recording" : "Вы спынілі відэазапіс",
    "{actor} started the audio recording" : "{actor} пачаў(-ла) аўдыязапіс",
    "You started the audio recording" : "Вы пачалі аўдыязапіс",
    "{actor} stopped the audio recording" : "{actor} спыніў(-ла) аўдыязапіс",
    "You stopped the audio recording" : "Вы спынілі аўдыязапіс",
    "The recording failed" : "Запіс не атрымаўся",
    "Someone voted on the poll {poll}" : "Хтосьці прагаласаваў у апытанні {poll}",
    "Message deleted by author" : "Паведамленне выдалена аўтарам",
    "Message deleted by {actor}" : "Паведамленне выдалена карыстальнікам {actor}",
    "Message deleted by you" : "Вы выдалілі паведамленне",
    "Deleted user" : "Выдалены карыстальнік",
    "Unknown number" : "Невядомы нумар",
    "Administration" : "Адміністратар",
    "System" : "Сістэма",
    "%s (guest)" : "%s (госць)",
    "Missed call" : "Прапушчаны выклік",
    "Call ended (Duration {duration})" : "Выклік завершаны (працягласць {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Выклік завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} завяршыў(-ла) выклік (працягласць {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Выклік з %n госцем завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})","Выклік з %n гасцямі завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})","Выклік з %n гасцямі завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})","Выклік з %n гасцямі завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Выклік з %n госцем завершаны (працягласць {duration})","Выклік з %n гасцямі завершаны (працягласць {duration})","Выклік з %n гасцямі завершаны (працягласць {duration})","Выклік з %n гасцямі завершаны (працягласць {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} завяршыў(-ла) выклік з %n госцем (працягласць {duration})","{actor} завяршыў(-ла) выклік з %n гасцямі (працягласць {duration})","{actor} завяршыў(-ла) выклік з %n гасцямі (працягласць {duration})","{actor} завяршыў(-ла) выклік з %n гасцямі (працягласць {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Выклік з {user1} завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})",
    "Call with {user1} ended (Duration {duration})" : "Выклік з {user1} завершаны (працягласць {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} завяршыў(-ла) выклік з {user1} (працягласць {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Выклік з {user1} і {user2} завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Выклік з {user1} і {user2} завершаны (працягласць {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} завяршыў(-ла) выклік з {user1} і {user2} (працягласць {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Выклік з {user1}, {user2} і {user3} завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Выклік з {user1}, {user2} і {user3} завершаны (працягласць {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} завяршыў(-ла) выклік з {user1}, {user2} і {user3} (працягласць {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Выклік з {user1}, {user2}, {user3} і {user4} завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Выклік з {user1}, {user2}, {user3} і {user4} завершаны (працягласць {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} завяршыў(-ла) выклік з {user1}, {user2}, {user3} і {user4} (працягласць {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Выклік з {user1}, {user2}, {user3}, {user4} і {user5} завершаны, бо дасягнуў максімальнай працягласці (працягласць {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Выклік з {user1}, {user2}, {user3}, {user4} і {user5} завершаны (працягласць {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} завяршыў(-ла) выклік з {user1}, {user2}, {user3}, {user4} і {user5} (працягласць {duration})",
    "Message of {user} in {conversation}" : "Паведамленне карыстальніка {user} у {conversation}",
    "Message of {user}" : "Паведамленне карыстальніка {user}",
    "Message of a deleted user in {conversation}" : "Паведамленне выдаленага карыстальніка ў {conversation}",
    "Talk conversations" : "Размовы ў Talk",
    "Call %s" : "Выклікаць %s",
    "An error occurred. Please contact your administrator." : "Узнікла памылка. Звярніцеся да адміністратара.",
    "App disabled" : "Праграма адключана",
    "Storage quota exceeded" : "Квота сховішча перавышана",
    "File not found" : "Файл не знойдзены",
    "File is not shared, or shared but not with the user" : "Файл не абагулены, або абагулены, але не з карыстальнікам",
    "No account available to delete." : "Няма ўліковых запісаў для выдалення.",
    "Poll" : "Апытанне",
    "Password needs to be set" : "Неабходна задаць пароль",
    "Uploading the file failed" : "Не ўдалося запампаваць файл",
    "File is too big" : "Файл занадта вялікі",
    "Invalid file provided" : "Прапанаваны файл некарэктны",
    "Invalid image" : "Памылковы відарыс",
    "Unknown filetype" : "Невядомы тып файла",
    "Talk mentions" : "Згадкі ў Talk",
    "More conversations" : "Больш размоў",
    "Say hi to your friends and colleagues!" : "Прывітайцеся з сябрамі і калегамі!",
    "No unread mentions" : "Няма непрачытаных згадак",
    "Call in progress" : "Выконваецца выклік",
    "You were mentioned" : "Вас згадалі",
    "Write to conversation" : "Напісаць у размову",
    "Writes event information into a conversation of your choice" : "Адпраўляе інфармацыю пра падзею ў выбраную вамі размову",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s запрасіў(-ла) вас у размову \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Вас запрасілі ў размову \"%s\".",
    "Conversation invitation" : "Запрашэнне ў размову",
    "Scheduled time" : "Запланаваны час",
    "Description" : "Апісанне",
    "Meeting ID" : "Ідэнтыфікатар сустрэчы",
    "Your PIN" : "Ваш PIN-код",
    "Click the button below to join the lobby now." : "Націсніце на кнопку, каб далучыцца да лобі зараз.",
    "Click the link below to join the lobby now." : "Націсніце на спасылку, каб далучыцца да лобі зараз.",
    "Join lobby for \"%s\"" : "Далучыцца да лобі \"%s\"",
    "Click the button below to join the conversation now." : "Націсніце на кнопку, каб далучыцца да размовы зараз.",
    "Click the link below to join the conversation now." : "Націсніце на спасылку, каб далучыцца да размовы зараз.",
    "Join \"%s\"" : "Далучыцца да \"%s\"",
    "Meeting" : "Сустрэча",
    "Password request: %s" : "Запыт пароля: %s",
    "Private conversation" : "Прыватная размова",
    "Deleted user (%s)" : "Выдалены карыстальнік (%s)",
    "Failed to upload call recording" : "Не ўдалося запампаваць запіс выкліку",
    "Share to chat" : "Абагуіць у чаце",
    "Dismiss notification" : "Адхіліць апавяшчэнне",
    "Call recording now available" : "Цяпер даступны запіс выклікаў",
    "The recording for the call in {call} was uploaded to {file}." : "Запіс выкліку ў {call} запампаваны ў {file}.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} запрасіў(-ла) вас далучыцца да {roomName} на {remoteServer}",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "Someone reacted" : "Хтосьці адрэагаваў",
    "New message" : "Новае паведамленне",
    "Reminder" : "Напамін",
    "Someone mentioned you" : "Хтосьці згадаў вас",
    "Notification" : "Апавяшчэнне",
    "Someone reacted in a private conversation" : "Хтосьці адрэагаваў у прыватнай размове",
    "You received a message in a private conversation" : "Вы атрымалі паведамленне ў прыватнай размове",
    "Reminder in a private conversation" : "Напамін у прыватнай размове",
    "Someone mentioned you in a private conversation" : "Хтосьці згадаў вас у прыватнай размове",
    "Notification in a private conversation" : "Апавяшчэнне ў прыватнай размове",
    "Reminder: You in {call}" : "Напамін: вы ў {call}",
    "Reminder: {user} in {call}" : "Напамін: {user} у {call}",
    "Reminder: Deleted user in {call}" : "Напамін: выдалены карыстальнік у {call}",
    "Reminder: {guest} (guest) in {call}" : "Напамін: {guest} (госць) у {call}",
    "Reminder: Guest in {call}" : "Напамін: госць у {call}",
    "{user} reacted with {reaction}" : "{user} адрэагаваў(-ла) з {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} адрэагаваў(-ла) з {reaction} у {call}",
    "Deleted user reacted with {reaction} in {call}" : "Выдалены карыстальнік адрэагаваў з {reaction} у {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (госць) адрэагаваў(-ла) з {reaction} у {call}",
    "Guest reacted with {reaction} in {call}" : "Госць адрэагаваў з {reaction} у {call}",
    "{user} in {call}" : "{user} у {call}",
    "Deleted user in {call}" : "Выдалены карыстальнік у {call}",
    "{guest} (guest) in {call}" : "{guest} (госць) у {call}",
    "Guest in {call}" : "Госць у {call}",
    "{user} sent you a private message" : "{user} адправіў(-ла) вам прыватнае паведамленне",
    "{user} sent a message in conversation {call}" : "{user} адправіў(-ла) паведамленне ў размове {call}",
    "A deleted user sent a message in conversation {call}" : "Выдалены карыстальнік адправіў паведамленне ў размове {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (госць) адправіў(-ла) паведамленне ў размове {call}",
    "A guest sent a message in conversation {call}" : "Гось адправіў паведамленне ў размове {call}",
    "{user} replied to your private message" : "{user} адказаў(-ла) на ваша прыватнае паведамленне",
    "{user} replied to your message in conversation {call}" : "{user} адказаў(-ла) на ваша паведамленне ў размове {call}",
    "A deleted user replied to your message in conversation {call}" : "Выдалены карыстальнік адказаў на ваша паведамленне ў размове {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (госць) адказаў(-ла) на ваша паведамленне ў размове {call}",
    "A guest replied to your message in conversation {call}" : "Госць адказаў на ваша паведамленне ў размове {call}",
    "Reminder: You in private conversation {call}" : "Напамін: вы ў прыватнай размове {call}",
    "Reminder: A deleted user in private conversation {call}" : "Напамін: выдалены карыстальнік у прыватнай размове {call}",
    "Reminder: {user} in private conversation" : "Напамін: {user} у прыватнай размове",
    "Reminder: You in conversation {call}" : "Напамін: вы ў размове {call}",
    "Reminder: {user} in conversation {call}" : "Напамін: {user} у размове {call}",
    "Reminder: A deleted user in conversation {call}" : "Напамін: выдалены карыстальнік у размове {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Напамін: {guest} (госць) у размове {call}",
    "Reminder: A guest in conversation {call}" : "Напамін: госць у размове {call}",
    "{user} reacted with {reaction} to your private message" : "{user} адрэагаваў(-ла) з {reaction} на ваша прыватане паведамленне",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} адрэагаваў(-ла) з {reaction} на ваша паведамленне ў размове {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Выдалены карыстальнік адрэагаваў з {reaction} на ваша паведамленне ў размове {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (госць) адрэагаваў(-ла) з {reaction} на ваша паведамленне ў размове {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Госць адрэагаваў з {reaction} на ваша паведамленне ў размове {call}",
    "{user} mentioned you in a private conversation" : "{user} згадаў(-ла) вас у прыватнай размове",
    "{user} mentioned group {group} in conversation {call}" : "{user} згадаў(-ла) групу {group} у размове {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} згадаў(-ла) каманду {team} у размове {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} згадаў(-ла) усіх у размове {call}",
    "{user} mentioned you in conversation {call}" : "{user} згадаў(-ла) вас у размове {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Выдалены карыстальнік згадаў групу {group} у размове {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Выдалены карыстальнік згадаў каманду {team} у размове {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Выдалены карыстальнік згадаў усіх у размове {call}",
    "A deleted user mentioned you in conversation {call}" : "Выдалены карыстальнік згадаў вас у размове {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (госць) згадаў(-ла) групу {group} у размове {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (госць) згадаў(-ла) каманду {team} у размове {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (госць) згадаў(-ла) усіх у размове {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (госць) згадаў(-ла) вас у размове {call}",
    "A guest mentioned group {group} in conversation {call}" : "Госць згадаў групу {group} у размове {call}",
    "A guest mentioned team {team} in conversation {call}" : "Госць згадаў каманду {team} у размове {call}",
    "A guest mentioned everyone in conversation {call}" : "Госць згадаў усіх у размове {call}",
    "A guest mentioned you in conversation {call}" : "Госць згадаў вас у размове {call}",
    "View message" : "Праглядзець паведамленне",
    "Dismiss reminder" : "Адхіліць напамін",
    "View chat" : "Праглядзець чат",
    "{user} invited you to a group conversation: {call}" : "{user} запрасіў(-ла) вас у групавую размову: {call}",
    "Join call" : "Далучыцца да выкліку",
    "Answer call" : "Адказаць на выклік",
    "{user} would like to talk with you" : "{user} хоча пагаварыць з вамі",
    "You missed a call from {user}" : "Вы прапусцілі выклік ад {user}",
    "Accept call" : "Прыняць выклік",
    "Incoming phone call from {call}" : "Уваходны тэлефонны выклік ад {call}",
    "You missed a phone call from {call}" : "Вы прапусцілі тэлефонны выклік ад {call}",
    "A group call has started in {call}" : "Групавы выклік пачаўся ў {call}",
    "You missed a group call in {call}" : "Вы прапусцілі групавы выклік у {call}",
    "{email} is requesting the password to access {file}" : "{email} запытвае пароль для доступу да {file}",
    "{email} tried to request the password to access {file}" : "{email} паспрабаваў(-ла) запытаць пароль для доступу да {file}",
    "Someone is requesting the password to access {file}" : "Хтосьці запытвае пароль для доступу да {file}",
    "Someone tried to request the password to access {file}" : "Хтосьці паспрабаваў запытаць пароль для доступу да {file}",
    "Open settings" : "Адкрыць налады",
    "pending" : "у чаканні",
    "active" : "актыўны",
    "expired" : "скончыўся тэрмін дзеяння",
    "blocked" : "заблакіраваны",
    "error" : "памылка",
    "The certificate of {host} expires in {days} days" : "Тэрмін дзеяння сертыфіката {host} заканчваецца праз {days} дзён",
    "The certificate of {host} expired" : "Тэрмін дзеяння сертыфіката {host} скончыўся",
    "Open Talk" : "Адкрыць Talk",
    "Default" : "Прадвызначаныя",
    "Webinar" : "Вэбінар",
    "Conversations" : "Размовы",
    "Messages in current conversation" : "Паведамленні ў бягучай размове",
    "{user}" : "{user}",
    "Messages" : "Паведамленні",
    "{user} in {conversation}" : "{user} у {conversation}",
    "Messages in other conversations" : "Паведамленні ў іншых размовах",
    "Invalid emoji character" : "Памылковы сімвал эмодзі",
    "Invalid background color" : "Памылковы колер фону",
    "Avatar image is not square" : "Відарыс аватара не квадратны",
    "Room {number}" : "Пакой {number}",
    "Favorites" : "Абранае",
    "Other" : "Іншае",
    "Something unexpected happened." : "Здарылася нешта нечаканае.",
    "An HTTPS URL is required." : "Патрабуецца URL-адрас HTTPS.",
    "The language is invalid." : "Мова памылковая.",
    "Too many requests are send from your servers address. Please try again later." : "З вашага адраса сервера адпраўлена занадта шмат запытаў. Паспрабуйце яшчэ раз пазней.",
    "Something unexpected happened. Please try again later." : "Здарылася нешта нечаканае. Паўтарыце спробу пазней.",
    "There is no such account registered." : "Такі ўліковы запіс не зарэгістраваны.",
    "Note to self" : "Асабістыя нататкі",
    "A place for your private notes, thoughts and ideas" : "Месца для вашых прыватных нататак, думак і ідэй",
    "Let's get started!" : "Пачнем!",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Вітаем у Nextcloud Talk\n\nNextcloud Talk — гэта прыватны і магутны месенджар, які інтэгруецца з Nextcloud. Удзельнічайце ў прыватных або групавых размовах, супрацоўнічайце праз галасавыя і відэазванкі, арганізуйце вэбінары і мерапрыемствы, наладжвайце свае размовы і многае іншае.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Вы можаце адказваць на паведамленні, перасылаць іх у іншыя чаты і людзям або капіяваць змесціва паведамленняў.",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Аб'яднаныя Арабскія Эміраты",
    "Afghanistan" : "Афганістан",
    "Antigua and Barbuda" : "Антыгуа і Барбуда",
    "Anguilla" : "Ангілья",
    "Albania" : "Албанія",
    "Armenia" : "Арменія",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктыка",
    "Argentina" : "Аргенціна",
    "American Samoa" : "Амерыканскае Самоа",
    "Austria" : "Аўстрыя",
    "Australia" : "Аўстралія",
    "Aruba" : "Аруба",
    "Åland Islands" : "Аландскія астравы",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Боснія і Герцагавіна",
    "Barbados" : "Барбадас",
    "Bangladesh" : "Бангладэш",
    "Belgium" : "Бельгія",
    "Burkina Faso" : "Буркіна-Фасо",
    "Bulgaria" : "Балгарыя",
    "Bahrain" : "Бахрэйн",
    "Burundi" : "Бурундзі",
    "Benin" : "Бенін",
    "Saint Barthélemy" : "Сен-Бартэльмі",
    "Bermuda" : "Бермудскія астравы",
    "Brunei Darussalam" : "Бруней-Дарусалам",
    "Bolivia, Plurinational State of" : "Балівія, Шматнацыянальная Дзяржава",
    "Bonaire, Sint Eustatius and Saba" : "Банайрэ, Сінт-Эстаціус і Саба",
    "Brazil" : "Бразілія",
    "Bahamas" : "Багамскія астравы",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "Востраў Бувэ",
    "Botswana" : "Батсвана",
    "Belarus" : "Беларусь",
    "Belize" : "Беліз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Какосавыя (Кілінг) астравы",
    "Congo, the Democratic Republic of the" : "Дэмакратычная Рэспубліка Конга",
    "Central African Republic" : "Цэнтральна-Афрыканская Рэспубліка",
    "Congo" : "Конга",
    "Switzerland" : "Швейцарыя",
    "Côte d'Ivoire" : "Кот-д'Івуар",
    "Cook Islands" : "Астравы Кука",
    "Chile" : "Чылі",
    "Cameroon" : "Камерун",
    "China" : "Кітай",
    "Colombia" : "Калумбія",
    "Costa Rica" : "Коста-Рыка",
    "Cuba" : "Куба",
    "Cabo Verde" : "Каба-Вердэ",
    "Curaçao" : "Кюрасаа",
    "Christmas Island" : "Востраў Каляд",
    "Cyprus" : "Кіпр",
    "Czechia" : "Чэхія",
    "Germany" : "Германія",
    "Djibouti" : "Джыбуці",
    "Denmark" : "Данія",
    "Dominica" : "Дамініка",
    "Dominican Republic" : "Дамініканская Рэспубліка",
    "Algeria" : "Алжыр",
    "Ecuador" : "Эквадор",
    "Estonia" : "Эстонія",
    "Egypt" : "Егіпет",
    "Western Sahara" : "Заходняя Сахара",
    "Eritrea" : "Эрытрэя",
    "Spain" : "Іспанія",
    "Ethiopia" : "Эфіопія",
    "Finland" : "Фінляндыя",
    "Fiji" : "Фіджы",
    "Falkland Islands (Malvinas)" : "Фалклендскія (Мальвінскія) астравы",
    "Micronesia, Federated States of" : "Мікранезія, Федэратыўныя Штаты",
    "Faroe Islands" : "Фарэрскія астравы",
    "France" : "Францыя",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Злучанае Каралеўства Вялікабрытаніі і Паўночнай Ірландыі",
    "Grenada" : "Грэнада",
    "Georgia" : "Грузія",
    "French Guiana" : "Французская Гвіяна",
    "Guernsey" : "Гернсі",
    "Ghana" : "Гана",
    "Gibraltar" : "Гібралтар",
    "Greenland" : "Грэнландыя",
    "Gambia" : "Гамбія",
    "Guinea" : "Гвінея",
    "Guadeloupe" : "Гвадэлупа",
    "Equatorial Guinea" : "Экватарыяльная Гвінея",
    "Greece" : "Грэцыя",
    "South Georgia and the South Sandwich Islands" : "Паўднёвая Георгія і Паўднёвыя Сандвічавы астравы",
    "Guatemala" : "Гватэмала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвінея-Бісау",
    "Guyana" : "Гаяна",
    "Hong Kong" : "Ганконг",
    "Heard Island and McDonald Islands" : "Астравы Херд і Макдональд",
    "Honduras" : "Гандурас",
    "Croatia" : "Харватыя",
    "Haiti" : "Гаіці",
    "Hungary" : "Венгрыя",
    "Indonesia" : "Інданезія",
    "Ireland" : "Ірландыя",
    "Israel" : "Ізраіль",
    "Isle of Man" : "Востраў Мэн",
    "India" : "Індыя",
    "British Indian Ocean Territory" : "Брытанская тэрыторыя ў Індыйскім акіяне",
    "Iraq" : "Ірак",
    "Iran, Islamic Republic of" : "Іран, Ісламская Рэспубліка",
    "Iceland" : "Ісландыя",
    "Italy" : "Італія",
    "Jersey" : "Джэрсі",
    "Jamaica" : "Ямайка",
    "Jordan" : "Іарданія",
    "Japan" : "Японія",
    "Kenya" : "Кенія",
    "Kyrgyzstan" : "Кыргызстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кірыбаці",
    "Comoros" : "Каморскія астравы",
    "Saint Kitts and Nevis" : "Сент-Кітс і Невіс",
    "Korea, Democratic People's Republic of" : "Карэйская Народна-Дэмакратычная Рэспубліка",
    "Korea, Republic of" : "Карэйская Рэспубліка",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманавы астравы",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаоская Народна-Дэмакратычная Рэспубліка",
    "Lebanon" : "Ліван",
    "Saint Lucia" : "Сент-Люсія",
    "Liechtenstein" : "Ліхтэнштэйн",
    "Sri Lanka" : "Шры-Ланка",
    "Liberia" : "Ліберыя",
    "Lesotho" : "Лесота",
    "Lithuania" : "Літва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвія",
    "Libya" : "Лівія",
    "Morocco" : "Марока",
    "Monaco" : "Манака",
    "Moldova, Republic of" : "Малдова, Рэспубліка",
    "Montenegro" : "Чарнагорыя",
    "Saint Martin (French part)" : "Сен-Мартэн (французская частка)",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалавы астравы",
    "North Macedonia" : "Паўночная Македонія",
    "Mali" : "Малі",
    "Myanmar" : "М’янма",
    "Mongolia" : "Манголія",
    "Macao" : "Макаа",
    "Northern Mariana Islands" : "Паўночныя Марыянскія астравы",
    "Martinique" : "Марцініка",
    "Mauritania" : "Маўрытанія",
    "Montserrat" : "Мантсерат",
    "Malta" : "Мальта",
    "Mauritius" : "Маўрыкій",
    "Maldives" : "Мальдывы",
    "Malawi" : "Малаві",
    "Mexico" : "Мексіка",
    "Malaysia" : "Малайзія",
    "Mozambique" : "Мазамбік",
    "Namibia" : "Намібія",
    "New Caledonia" : "Новая Каледонія",
    "Niger" : "Нігер",
    "Norfolk Island" : "Востраў Норфалк",
    "Nigeria" : "Нігерыя",
    "Nicaragua" : "Нікарагуа",
    "Netherlands" : "Нідэрланды",
    "Norway" : "Нарвегія",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ніуэ",
    "New Zealand" : "Новая Зеландыя",
    "Oman" : "Аман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Французская Палінезія",
    "Papua New Guinea" : "Папуа-Новая Гвінея",
    "Philippines" : "Філіпіны",
    "Pakistan" : "Пакістан",
    "Poland" : "Польшча",
    "Saint Pierre and Miquelon" : "Сен-П’ер і Мікелон",
    "Pitcairn" : "Астравы Піткэрн",
    "Puerto Rico" : "Пуэрта-Рыка",
    "Palestine, State of" : "Палесціна, Дзяржава",
    "Portugal" : "Партугалія",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Рэюньён",
    "Romania" : "Румынія",
    "Serbia" : "Сербія",
    "Russian Federation" : "Расійская Федэрацыя",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудаўская Аравія",
    "Solomon Islands" : "Саламонавы астравы",
    "Seychelles" : "Сейшэльскія астравы",
    "Sudan" : "Судан",
    "Sweden" : "Швецыя",
    "Singapore" : "Сінгапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Астравы святой Алены, Узнясення і Трыстан-да-Кунья",
    "Slovenia" : "Славенія",
    "Svalbard and Jan Mayen" : "Шпіцберген і Ян-Маен",
    "Slovakia" : "Славакія",
    "Sierra Leone" : "Сьера-Леонэ",
    "San Marino" : "Сан-Марына",
    "Senegal" : "Сенегал",
    "Somalia" : "Самалі",
    "Suriname" : "Сурынам",
    "South Sudan" : "Паўднёвы Судан",
    "Sao Tome and Principe" : "Сан-Тамэ і Прынсіпі",
    "El Salvador" : "Сальвадор",
    "Sint Maarten (Dutch part)" : "Сінт-Мартэн (нідэрландская частка)",
    "Syrian Arab Republic" : "Сірыйская Арабская Рэспубліка",
    "Eswatini" : "Эсваціні",
    "Turks and Caicos Islands" : "Астравы Цёркс і Кайкас",
    "Chad" : "Чад",
    "French Southern Territories" : "Французскія Паўднёвыя Тэрыторыі",
    "Togo" : "Тога",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджыкістан",
    "Tokelau" : "Такелау",
    "Timor-Leste" : "Тымор-Лешці",
    "Turkmenistan" : "Туркменістан",
    "Tunisia" : "Туніс",
    "Tonga" : "Тонга",
    "Turkey" : "Турцыя",
    "Trinidad and Tobago" : "Трынідад і Табага",
    "Tuvalu" : "Тувалу",
    "Taiwan, Province of China" : "Тайвань, правінцыя Кітая",
    "Tanzania, United Republic of" : "Танзанія, Аб'яднаная Рэспубліка",
    "Ukraine" : "Украіна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малыя Аддаленыя астравы ЗША",
    "United States of America" : "Злучаныя Штаты Амерыкі",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекістан",
    "Holy See" : "Святы Пасад",
    "Saint Vincent and the Grenadines" : "Сент-Вінсент і Грэнадзіны",
    "Venezuela, Bolivarian Republic of" : "Венесуэла, Баліварыянская Рэспубліка",
    "Virgin Islands, British" : "Віргінскія астравы, Брытанскія",
    "Virgin Islands, U.S." : "Віргінскія астравы, ЗША",
    "Viet Nam" : "В'етнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уоліс і Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Емен",
    "Mayotte" : "Маёта",
    "South Africa" : "Паўднёва-Афрыканская Рэспубліка",
    "Zambia" : "Замбія",
    "Zimbabwe" : "Зімбабвэ",
    "Background blur" : "Размытасць фону",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Ваш вэб-сервер няправільна наладжаны для дастаўкі файлаў `.wasm`. Звычайна гэта праблема канфігурацыі Nginx. Для размытасці фону неабходна ўнесці карэктывы ў канфігурацыю Nginx таксама для дастаўкі файлаў `.wasm`. Параўнайце канфігурацыю Nginx з рэкамендаванай у нашай дакументацыі.",
    "Talk configuration values" : "Значэнні канфігурацыі Talk",
    "Federation" : "Федэрацыя",
    "Error: Cannot connect to server" : "Памылка: немагчыма злучыцца з серверам",
    "Error: Server did not respond with proper JSON" : "Памылка: сервер не адказаў правільным JSON",
    "Error: Certificate expired" : "Памылка: тэрмін дзеяння сертыфіката скончыўся",
    "Could not get version" : "Не ўдалося атрымаць версію",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Памылка: запушчана версія: {version}; неабходна абнавіць сервер для сумяшчальнасці з гэтай версіяй Talk.",
    "Error: Server responded with: {error}" : "Памылка: адказ сервера: {error}",
    "Error: Unknown error occurred" : "Памылка: Узнікла невядомая памылка",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Увага: запушчана версія: {version}; Сервер не падтрымлівае ўсе функцыі гэтай версіі Talk, адсутнічаюць функцыі: {features}",
    "SIP configuration" : "Канфігурацыя SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Памылковая дата, дата павінна быць у фармаце ГГГГ-ММ-ДД",
    "Conversation not found" : "Размова не знойдзена",
    "Path is already shared with this conversation" : "Шлях ужо абагулены ў гэтай размове",
    "Chat, video & audio-conferencing using WebRTC" : "Чат, відэа- і аўдыяканферэнцыі з выкарыстаннем WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Чат, відэа- і аўдыяканферэнцыі з выкарыстаннем WebRTC\n\n* 💬 **Чат** Nextcloud Talk - гэта просты тэкставы чат, які дазваляе вам абагульваць або запампоўваць файлы з праграмы Файлы Nextcloud або лакальнай прылады і згадваць іншых удзельнікаў..\n* 👥 **Прыватныя, групавыя, публічныя і абароненыя паролем выклікі!** Запрашайце каго-небудзь, усю групу або адпраўляйце публічную спасылку, каб запрасіць на выклік.\n* 🌐 **Федэратыўныя чаты** Чат з іншымі карыстальнікамі Nextcloud на іх серверах\n* 💻 **Абагульванне экрана!** Паказвайце свой экран удзельнікам выкліку.\n* 🚀 **Інтэграцыя з іншымі праграмамі Nextcloud**, такімі як Файлы, Каляндар, Статус карыстальніка, Панэль кіравання, Flow, Карты, Smart picker, Кантакты, Карткі, і многімі іншымі.\n* 🌉 **Сінхранізацыя з іншымі месенджарамі** Дзякуючы інтэграцыі [Matterbridge](https://github.com/42wim/matterbridge/) у Talk, вы можаце лёгка сінхранізаваць мноства іншых месенджараў з Nextcloud Talk і наадварот.",
    "Leave call" : "Выйсці з выкліку",
    "Stay in call" : "Застацца ў выкліку",
    "Error occurred when getting the conversation information" : "Памылка пры атрыманні інфармацыі пра размову",
    "Duplicate session" : "Дубляваць сеанс",
    "Discuss this file" : "Абмеркаваць гэты файл",
    "Loading …" : "Загрузка …",
    "Share this file with others to discuss it" : "Абагульце гэты файл з іншымі, каб абмеркаваць яго",
    "Join conversation" : "Далучыцца да размовы",
    "Share this file" : "Абагуліць гэты файл",
    "Error occurred when joining the conversation" : "Памылка пры далучэнні да размовы",
    "The password is wrong. Try again." : "Пароль няправільны. Паспрабуйце яшчэ раз.",
    "Password" : "Пароль",
    "Submit" : "Адправіць",
    "Error requesting the password." : "Памылка пры запыце пароля.",
    "Request password" : "Запытаць пароль",
    "This conversation has ended" : "Гэтая размова завершана.",
    "Close Talk sidebar" : "Закрыць бакавую панэль Talk",
    "Open Talk sidebar" : "Адкрыць бакавую панэль Talk",
    "Everyone" : "Усе",
    "Users and moderators" : "Карыстальнікі і мадэратары",
    "Moderators only" : "Толькі мадэратары",
    "Disable calls" : "Адключыць выклікі",
    "Save changes" : "Захаваць змены",
    "Saving …" : "Захаванне …",
    "Saved!" : "Захавана!",
    "Guests can still join public conversations." : "Госці ўсё яшчэ могуць далучацца да публічных размоў.",
    "Limit using Talk" : "Абмежаваць выкарыстанне Talk",
    "Limit creating a public and group conversation" : "Абмежаваць стварэнне публічных і групавых размоў",
    "Limit creating conversations" : "Абмежаваць стварэнне размоў",
    "Limit starting a call" : "Абмежаваць пачатак выкліку",
    "Limit starting calls" : "Абмежаваць пачатак выклікаў",
    "When a call has started, everyone with access to the conversation can join the call." : "Калі пачаўся выклік, да яго могуць далучыцца ўсе, хто мае доступ да размовы.",
    "Enabled" : "Уключаны",
    "Disabled" : "Адключаны",
    "Bots settings" : "Налады ботаў",
    "State" : "Статус",
    "Name" : "Назва",
    "Last error" : "Апошняя памылка",
    "Total errors count" : "Усяго памылак",
    "Find more bots" : "Знайсці больш ботаў",
    "Beta" : "Бэта",
    "Permissions" : "Дазволы",
    "Select groups …" : "Выберыце групы …",
    "All messages" : "Усе паведамленні",
    "@-mentions only" : "Толькі згадкі з @",
    "Off" : "Выкл.",
    "General settings" : "Агульныя налады",
    "Default notification settings" : "Прадвызначаныя налады апавяшчэнняў",
    "Integration into other apps" : "Інтэграцыя ў іншыя праграмы",
    "End-to-end encrypted calls" : "Скразное шыфраванне выклікаў",
    "Enable encryption" : "Уключыць шыфраванне",
    "Pending" : "У чаканні",
    "Error" : "Памылка",
    "Blocked" : "Заблакіраваны",
    "Active" : "Актыўны",
    "Expired" : "Скончыўся тэрмін дзеяння",
    "Never" : "Ніколі",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Калі ваш высокапрадукцыйны бэкэнд уключае функцыянальнасць STUN і/або TURN, налады будуць абноўлены адпаведна.",
    "Language" : "Мова",
    "Country" : "Краіна",
    "Status" : "Статус",
    "Created at" : "Створана",
    "STUN included" : "STUN уключаны",
    "Yes" : "Так",
    "No" : "Не",
    "_%n user_::_%n users_" : ["%n карыстальнік","%n карыстальнікі","%n карыстальнікаў","%n карыстальнікаў"],
    "Installed version: {version}" : "Усталяваная версія: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Вы можаце ўсталяваць Matterbridge, каб звязаць NextCloud Talk з некаторымі іншымі сэрвісамі. Наведайце іх {linkstart1}старонку на GitHub{linkend} для больш падрабязнай інфармацыі. Загрузка і ўсталяванне праграмы можа заняць некаторы час. У выпадку перавышэння часу чакання усталюйце яго ўручную з {linkstart2}NextCloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Бінарны файл Matterbridge мае няправільныя правы доступу. Пераканайцеся, што бінарны файл Matterbridge належыць патрэбнаму карыстальніку і можа быць выкананы. Яго можна знайсці ў \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Бінарны файл Matterbridge не знойдзены або не можа быць выкананы.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Вы таксама можаце ўручную задаць шлях да бінарнага файла Matterbridge праз канфігурацыю. Больш падрабязную інфармацыю глядзіце ў {linkstart}дакументацыі па інтэграцыі Matterbridge{linkend}.",
    "Downloading …" : "Спампоўванне …",
    "Install Talk Matterbridge" : "Усталяваць Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Падчас усталявання праграмы Matterbridge адбылася памылка",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Падчас усталявання Talk Matterbridge адбылася памылка. Усталюйце яго ўручную.",
    "Failed to execute Matterbridge binary." : "Не атрымалася выканаць двайковы файл Matterbridge.",
    "Matterbridge integration" : "Інтэграцыя з Matterbridge",
    "Enable Matterbridge integration" : "Уключыць інтэграцыю з Matterbridge",
    "Status: Checking connection" : "Стан: праверка злучэння",
    "OK: Running version: {version}" : "ОК: запушчаная версія: {version}",
    "Validate SSL certificate" : "Праверыць SSL-сертыфікат",
    "Delete this server" : "Выдаліць гэты сервер",
    "Recording consent" : "Згода на запіс",
    "Available features" : "Даступныя функцыі",
    "Error code" : "Код памылкі",
    "Error message" : "Паведамленне пра памылку",
    "High-performance backend URL" : "URL-адрас высокапрадукцыйнага бэкенда",
    "Nextcloud Talk setup not complete" : "Наладка Nextcloud Talk не завершана",
    "Nextcloud portal" : "Партал Nextcloud",
    "Quick installation guide" : "Кароткае кіраўніцтва па ўсталяванні",
    "STUN server URL" : "URL-адрас STUN-сервера",
    "STUN settings saved" : "Налады STUN захаваны",
    "STUN servers" : "STUN-серверы",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-сервер выкарыстоўваецца для вызначэння публічнага IP-адраса ўдзельнікаў, якія знаходзяцца за маршрутызатарам.",
    "Add a new STUN server" : "Дадаць новы STUN-сервер",
    "{option1} and {option2}" : "{option1} і {option2}",
    "{option} only" : "Толькі {option}",
    "Failed" : "Не ўдалося",
    "OK" : "OK",
    "Checking …" : "Праверка …",
    "Federated user" : "Федэратыўны карыстальнік",
    "Configure breakout rooms" : "Наладзіць групавыя пакоі",
    "Number of breakout rooms" : "Колькасць групавых пакояў",
    "You can create from 1 to 20 breakout rooms." : "Вы можаце стварыць ад 1 да 20 групавых пакояў.",
    "Confirm" : "Пацвердзіць",
    "Create breakout rooms" : "Стварыць групавыя пакоі",
    "Reset" : "Скінуць",
    "Delete breakout rooms" : "Выдаліць групавыя пакоі",
    "Room {roomNumber}" : "Пакой {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Бягучыя групавыя пакоі і налады будуць страчаны",
    "Cancel" : "Скасаваць",
    "Back" : "Назад",
    "Add participant \"{user}\"" : "Дадаць удзельніка \"{user}\"",
    "Now" : "Зараз",
    "Unknown error occurred" : "Узнікла невядомая памылка",
    "{participant0} will receive an invitation" : "{participant0} атрымае запрашэнне",
    "{participant0} and {participant1} will receive invitations" : "{participant0} і {participant1} атрымаюць запрашэнні",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} і яшчэ %n атрымаюць запрашэнні","{participant0}, {participant1} і яшчэ %n атрымаюць запрашэнні","{participant0}, {participant1} і яшчэ %n атрымаюць запрашэнні","{participant0}, {participant1} і яшчэ %n атрымаюць запрашэнні"],
    "Invite {user}" : "Запрасіць {user}",
    "Meeting created" : "Сустрэча створана",
    "Upcoming meetings" : "Будучыя сустрэчы",
    "No upcoming meetings" : "Няма будучых сустрэч",
    "Schedule a meeting" : "Запланаваць сустрэчу",
    "Meeting title" : "Загаловак сустрэчы",
    "From" : "З",
    "To" : "Да",
    "Calendar" : "Каляндар",
    "Attendees" : "Удзельнікі",
    "No other participants to send invitations to." : "Больш няма удзельнікаў, якім можна было б адправіць запрашэнні.",
    "Add attendees" : "Дадаць удзельнікаў",
    "Save" : "Захаваць",
    "Search participants" : "Пошук удзельнікаў",
    "No results" : "Няма вынікаў",
    "Done" : "Гатова",
    "Original language: {languageName}" : "Арыгінальная мова: {languageName}",
    "Translated language" : "Мова перакладу",
    "Translated language: {languageName}" : "Мова перакладу: {languageName}",
    "Exit full screen (F)" : "Выйсці з поўнаэкраннага рэжыму (F)",
    "Full screen (F)" : "На ўвесь экран (F)",
    "Recording consent is required" : "Патрабуецца згода на запіс",
    "This conversation is read-only" : "Размова у рэжыме \"толькі для чытання\"",
    "Conversation not found or not joined" : "Размова не знойдзена або вы да яе не далучыліся",
    "Lobby is still active and you're not a moderator" : "Лобі ўсё яшчэ актыўнае, і вы не мадэратар",
    "Connection failed" : "Не ўдалося злучыцца",
    "Reload" : "Перазагрузіць",
    "{nickName} raised their hand." : "{nickName} падняў(-ла) руку",
    "A participant raised their hand." : "Удзельнікаў падняў руку.",
    "Collapse stripe" : "Згарнуць паласу",
    "Expand stripe" : "Разгарнуць паласу",
    "Previous page of videos" : "Папярэдняя старонка відэа",
    "Next page of videos" : "Наступная старонка відэа",
    "Connecting …" : "Злучэнне …",
    "Calling …" : "Выклік …",
    "You can invite others in the participant tab of the sidebar" : "Вы можаце запрасіць іншых на ўкладцы ўдзельнікаў на бакавой панэлі",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Вы можаце запрасіць іншых на ўкладцы ўдзельнікаў на бакавой панэлі або абагуліўшы гэту спасылку!",
    "Share this link to invite others!" : "Абагульце гэту спасылку, каб запрасіць іншых!",
    "Copy link" : "Скапіяваць спасылку",
    "You are not allowed to enable audio" : "Вам не дазволена ўключаць гук",
    "No audio. Click to select device" : "Няма гуку. Націсніце, каб выбраць прыладу",
    "Mute audio" : "Адключыць гук",
    "Mute audio (M)" : "Адключыць гук (M)",
    "Unmute audio" : "Уключыць гук",
    "Unmute audio (M)" : "Уключыць гук (M)",
    "None" : "Няма",
    "Select a microphone" : "Выберыце мікрафон",
    "Select a speaker" : "Выберыце дынамік",
    "Microphone settings" : "Налады мікрафона",
    "Check devices" : "Праверыць прылады",
    "Access to camera was denied" : "Доступ да камеры забаронены",
    "Error while accessing camera: It is likely in use by another program" : "Памылка доступу да камеры: верагодна, яна выкарыстоўваецца іншай праграмай",
    "Error while accessing camera" : "Памылка доступу да камеры",
    "You have been muted by a moderator" : "Мадэратар адключыў вам мікрафон",
    "Hide presenter video" : "Схаваць відэа дакладчыка",
    "You are not allowed to enable video" : "Вам не дазволена ўключаць відэа",
    "No video. Click to select device" : "Няма відэа. Націсніце, каб выбраць прыладу",
    "Disable video" : "Адключыць відэа",
    "Disable video (V)" : "Адключыць відэа (V)",
    "Enable video" : "Уключыць відэа",
    "Enable video (V)" : "Уключыць відэа (V)",
    "Select a video device" : "Выберыце відэапрыладу",
    "Show presenter" : "Паказаць дакладчыка",
    "You" : "Вы",
    "Mute" : "Адключыць гук",
    "Muted" : "Адключаны гук",
    "Show screen" : "Паказаць экран",
    "Connection could not be established …" : "Не ўдалося ўсталяваць злучэнне...",
    "Connection was lost and could not be re-established …" : "Злучэнне было страчана і не можа быць адноўлена…",
    "Connection could not be established. Trying again …" : "Не ўдалося ўсталяваць злучэнне. Паўторная спроба…",
    "Connection lost. Trying to reconnect …" : "Злучэнне страчана. Спроба аднавіць злучэнне…",
    "Connection problems …" : "Праблемы са злучэннем…",
    "Collapse" : "Згарнуць",
    "Expand" : "Разгарнуць",
    "You need to be logged in to upload files" : "Каб запампоўваць файлы, вам трэба ўвайсці ў сістэму",
    "Drop your files to upload" : "Перацягніце файлы для запампоўвання",
    "Conversation messages" : "Паведамленні ў размове",
    "Scroll to bottom" : "Прагартаць уніз",
    "Post message" : "Апублікаваць паведамленне",
    "Federated conversation" : "Федэратыўная размова",
    "Public conversation" : "Публічная размова",
    "Favorite" : "Абранае",
    "Banned users" : "Заблакіраваныя карыстальнікі",
    "Manage the list of banned users in this conversation." : "Кіраванне спісам заблакіраваных карыстальнікаў у гэтай размове.",
    "Manage bans" : "Кіраванне блакіроўкамі",
    "No banned users" : "Няма заблакіраваных карыстальнікаў",
    "Banned by:" : "Заблакіраваны карыстальнікам:",
    "Date:" : "Дата:",
    "Note:" : "Заўвага:",
    "Hide details" : "Схаваць падрабязнасці",
    "Show details" : "Паказаць падрабязнасці",
    "Unban" : "Разблакіраваць",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Вы можаце змяніць назву і апісанне ў {linkstart}Календары ↗{linkend}.",
    "Error while updating conversation name" : "Памылка пры абнаўленні назвы размовы",
    "Error while updating conversation description" : "Памылка пры абнаўленні апісання размовы",
    "Enter a name for this conversation" : "Увядзіце назву для гэтай размовы",
    "Edit conversation name" : "Рэдагаваць назву размовы",
    "Edit conversation description" : "Рэдагаваць апісанне размовы",
    "Enter a description for this conversation" : "Увядзіце апісанне гэтай размовы",
    "Picture" : "Аватар",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "У гэтай размове можна ўключыць наступных ботаў. Звярніцеся да адміністратара, каб усталяваць больш ботаў на серверы.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "На гэтым серверы не ўсталяваны боты. Звярніцеся да адміністратара, каб усталяваць ботаў.",
    "Disable" : "Адключыць",
    "Enable" : "Уключыць",
    "Breakout rooms" : "Групавыя пакоі",
    "Manage breakout rooms" : "Кіраваць групавымі пакоямі",
    "Set up breakout rooms for this conversation" : "Задаць групавыя пакоі для гэтай размовы",
    "Choose your conversation picture" : "Выберыце аватар размовы",
    "Choose" : "Выбраць",
    "Error setting conversation picture" : "Памылка задання аватара размовы",
    "Could not set the conversation picture: {error}" : "Не ўдалося задаць аватар размовы: {error}",
    "Error cropping conversation picture" : "Памылка абрэзкі аватара размовы",
    "Error removing conversation picture" : "Памылка выдалення аватара размовы",
    "Set emoji as conversation picture" : "Задаць эмодзі ў якасці аватара размовы",
    "Set background color for conversation picture" : "Задаць фонавы колер для аватара размовы",
    "Upload conversation picture" : "Запампаваць аватар размовы",
    "Choose conversation picture from files" : "Выбраць аватар размовы з Файлаў",
    "Remove conversation picture" : "Выдаліць аватар размовы",
    "The file must be a PNG or JPG" : "Файл павінен быць у фармаце PNG або JPG",
    "Set picture" : "Задаць аватар",
    "Default permissions modified for {conversationName}" : "Зменены прадвызначаныя дазволы для {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Не ўдалося змяніць прадвызначаныя дазволы для {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Рэдагаваць прадвызначаныя дазволы для ўдзельнікаў гэтай размовы. Гэтыя налады не ўплываюць на мадэратараў.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Пасля кожнай змены дазволаў у гэтым раздзеле карыстальніцкія дазволы, раней прызначаныя асобным удзельнікам, будуць страчаны.",
    "All permissions" : "Усе дазволы",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Удзельнікі маюць дазвол пачынаць выклік, далучацца да выкліку, уключаць аўдыя і відэа, а таксама паказваць экран.",
    "Restricted" : "Абмежавана",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Удзельнікі могуць далучацца да выклікаў, але не могуць уключаць аўдыя, відэа і паказваць экран, пакуль мадэратар не дасць ім дазволы ўручную.",
    "Advanced permissions" : "Пашыраныя дазволы",
    "Edit permissions" : "Рэдагаваць дазволы",
    "Conversation settings" : "Налады размовы",
    "Basic Info" : "Асноўныя звесткі",
    "Personal" : "Асабістыя",
    "Moderation" : "Мадэрацыя",
    "Breakout Rooms" : "Групавыя пакоі",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Боты",
    "Danger zone" : "Небяспечная зона",
    "Archive conversation" : "Архіваваць размову",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Архіваваныя размовы прадвызначна схаваныя ў спісе размоў. Аднак яны ўсё роўна будуць адлюстроўвацца, калі вы будзеце шукаць па назве размовы або адкрываць спіс архіваваных размоў.",
    "Do you really want to leave \"{displayName}\"?" : "Вы сапраўды хочаце выйсці з \"{displayName}\"?",
    "You can archive this conversation instead." : "Замест гэтага вы можаце архіваваць гэтую размову.",
    "Leave conversation" : "Выйсці з размовы",
    "You need to promote a new moderator before you can leave the conversation" : "Перш чым пакінуць размову, вам трэба прызначыць новага мадэратара",
    "Delete conversation" : "Выдаліць размову",
    "Do you really want to delete \"{displayName}\"?" : "Вы сапраўды хочаце выдаліць \"{displayName}\"?",
    "Error while deleting conversation" : "Памылка пры выдаленні размовы",
    "Delete all chat messages" : "Выдаліць усе паведамленні ў чаце",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Вы сапраўды хочаце выдаліць усе паведамленні ў \"{displayName}\"?",
    "Error while clearing chat history" : "Памылка пры ачыстцы гісторыі чата",
    "Be careful, these actions cannot be undone." : "Будзьце ўважлівыя, гэтыя дзеянні нельга адрабіць.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Каб зноў далучыцца да закрытай размовы пасля таго, я вы выйдзеце з яе, спатрэбіцца запрашэнне. Да адкрытай размовы можна далучыцца ў любы час.",
    "Permanently delete this conversation." : "Назаўжды выдаліць гэту размову.",
    "Delete chat messages" : "Выдаліць паведамленні ў чаце",
    "Permanently delete all the messages in this conversation." : "Назаўжды выдаліць усе паведамленні ў гэтай размове.",
    "Custom expiration time" : "Карыстальніцкі тэрмін дзеяння",
    "Message expiration disabled" : "Тэрмін дзеяння паведамленняў адключаны",
    "Message expiration set: {duration}" : "Зададзены тэрмін дзеяння паведамленняў: {duration}",
    "Error when trying to set message expiration" : "Памылка пры спробе задаць тэрмін дзеяння паведамленняў",
    "Message expiration" : "Тэрмін дзеяння паведамленняў",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Тэрмін дзеяння паведамленняў у чаце можа скончыцца праз пэўны час. Заўвага: файлы, абагуленыя ў чаце, не будуць выдалены для ўладальніка, але больш не будуць абагулены ў размове.",
    "Set message expiration" : "Задаць тэрмін дзеяння паведамленняў",
    "Current message expiration" : "Бягучы тэрмін дзеяння паведамленняў",
    "Password copied to clipboard" : "Пароль скапіяваны ў буфер абмену",
    "Password could not be copied" : "Не ўдалося скапіяваць пароль",
    "Guest access" : "Гасцявы доступ",
    "Breakout rooms are not allowed in public conversations." : "У публічных размовах не дапускаюцца групавыя пакоі.",
    "Allow guests to join this conversation via link" : "Дазволіць гасцям далучацца да размовы па спасылцы",
    "Password protection" : "Абарона паролем",
    "This conversation is password-protected. Guests need password to join" : "Гэта размова абаронена паролем. Гасцям патрэбен пароль для далучэння.",
    "Password protection is needed for public conversations" : "Публічным размовам патрэбна абарона паролем",
    "Set a password" : "Задайце пароль",
    "Change password" : "Змяніць пароль",
    "Enter new password" : "Увядзіце новы пароль",
    "Save password" : "Захаваць пароль",
    "Copy password" : "Скапіяваць пароль",
    "Guests are allowed to join this conversation via link" : "Госці могуць далучыцца да гэтай размовы па спасылцы",
    "Guests are not allowed to join this conversation" : "Гасцям не дазваляецца далучацца да гэтай размовы",
    "Resend invitations" : "Адправіць запрашэнні паўторна",
    "This conversation is open to registered users" : "Гэта размова адкрыта для зарэгістраваных карыстальнікаў",
    "Open conversation" : "Адкрыць размову",
    "Set language spoken in calls" : "Задаць мову размовы падчас выклікаў",
    "Languages could not be loaded" : "Не ўдалося загрузіць мовы",
    "Loading languages …" : "Загрузка моў …",
    "Invalid language" : "Памылковая мова",
    "Default language (English)" : "Прадвызначаная мова (Англійская)",
    "Start time: {date}" : "Час пачатку: {date}",
    "Start time has been updated" : "Час пачатку абноўлены.",
    "Error occurred while updating start time" : "Падчас абнаўлення часу пачатку адбылася памылка",
    "Meeting start time" : "Час пачатку сустрэчы",
    "Start time (optional)" : "Час пачатку (неабавязкова)",
    "Poll drafts" : "Чарнавікі апытанняў",
    "Browse poll drafts" : "Праглядзець чарнавікі апытанняў",
    "Error occurred when locking the conversation" : "Памылка пры блакіраванні размовы",
    "Error occurred when unlocking the conversation" : "Памылка пры разблакіраванні размовы",
    "Lock conversation" : "Заблакіраваць размову",
    "This will also terminate the ongoing call." : "Гэта таксама перапыніць бягучы выклік.",
    "Edit" : "Рэдагаваць",
    "More information" : "Больш інфармацыі",
    "Delete" : "Выдаліць",
    "not running, check Matterbridge log" : "не запушчана, праверце журнал Matterbridge",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "З дапамогай Matterbridge вы можаце злучаць каналы з розных сістэм імгненных паведамленняў.",
    "More info on Matterbridge" : "Больш інфармацыі пра Matterbridge",
    "Show Matterbridge log" : "Паказаць журнал Matterbridge",
    "Log content" : "Змест журнала",
    "Only moderators are allowed to mention @all" : "Толькі мадэратары могуць згадваць @all",
    "All participants are allowed to mention @all" : "Усе ўдзельнікі могуць згадваць @all",
    "Participants are now allowed to mention @all." : "Цяпер удзельнікам дазваляецца згадваць @all.",
    "Mentioning @all has been limited to moderators." : "Згадваць @all дазволена толькі мадэратарам.",
    "Allow participants to mention @all" : "Дазволіць удзельнікам згадваць @all",
    "Mention permissions" : "Дазволы на згадванне",
    "Notifications" : "Апавяшчэнні",
    "Notify about calls in this conversation" : "Апавяшчаць пра выклікі ў гэтай размове",
    "Important conversation" : "Важная размова",
    "\"Do not disturb\" user status is ignored for important conversations" : "Статус карыстальніка \"Не турбаваць\" ігнаруецца падчас важных размоў",
    "Sensitive conversation" : "Сакрэтная размова",
    "Message preview will be disabled in conversation list and notifications" : "Перадпрагляд паведамленняў будзе адключаны ў спісе размоў і апавяшчэннях",
    "Recording consent is required for calls in this conversation" : "Для запісу выклікаў у гэтай размове патрабуецца згода",
    "Recording consent is not required for calls in this conversation" : "Для запісу выклікаў у гэтай размове не патрабуецца згода",
    "Recording consent requirement was updated" : "Патрабаванне аб згодзе на запіс было абноўлена",
    "Error occurred while updating recording consent" : "Падчас абнаўлення згоды на запіс узнікла памылка",
    "Recording Consent" : "Згода на запіс",
    "Require recording consent before joining call in this conversation" : "Патрабаваць згоду на запіс перад далучэннем да выкліку ў гэтай размове",
    "Recording consent is required for all calls" : "Для ўсіх выклікаў патрабуецца згода на запіс",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n чалавек прыняты","%n чалавекі прыняты","%n чалавек прынята","%n чалавек прынята"],
    "_%n person declined_::_%n people declined_" : ["%n чалавек адхілены","%n чалавекі адхілены","%n чалавек адхілена","%n чалавек адхілена"],
    "_and %n other attachment_::_and %n other attachments_" : ["і яшчэ %n далучэнне","і яшчэ %n далучэнні","і яшчэ %n далучэнняў","і яшчэ %n далучэнняў"],
    "With {displayName}" : "З {displayName}",
    "In {conversation}" : "У {conversation}",
    "View attachment" : "Праглядзець далучэнне",
    "Join" : "Далучыцца",
    "View conversation" : "Праглядзець размову",
    "View event on Calendar" : "Праглядзець падзею ў Календары",
    "Error while creating the conversation" : "Памылка пры стварэнні размовы",
    "Hello, {displayName}" : "Вітаем, {displayName}",
    "Start meeting now" : "Пачаць сустрэчу",
    "Give your meeting a title" : "Дайце назву вашай сустрэчы",
    "Create and copy link" : "Стварыць і скапіяваць спасылку",
    "Create a new conversation" : "Стварыць новую размову",
    "Join open conversations" : "Далучыцца да адкрытых размоў",
    "Scroll backward" : "Прагартаць назад",
    "Scroll forward" : "Прагартаць наперад",
    "Schedule meetings" : "Плануйце сустрэчы",
    "You don't have any upcoming meetings" : "Няма запланаваных сустрэч",
    "Open calendar" : "Адкрыць каляндар",
    "Unread mentions" : "Непрачытаныя згадкі",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Тут будуць адлюстроўвацца паведамленні, у якіх вас згадвалі. Вы можаце згадваць людзей, набіраючы @, а затым іх імя.",
    "Upcoming reminders" : "Будучыя напаміны",
    "Message reminders" : "Напаміны пра паведамленні",
    "Set a reminder on a message to be notified" : "Задайце напамін для паведамлення, пра якое трэба атрымаць апавяшчэнне",
    "Start a group conversation" : "Пачаць групавую размову",
    "Create conversation" : "Стварыць размову",
    "Enter your name" : "Увядзіце сваё імя",
    "Submit name and join" : "Увядзіце імя і далучыцеся",
    "Do you already have an account?" : "У вас ужо ёсць уліковы запіс?",
    "Log in" : "Увайсці",
    "Error while verifying uploaded file" : "Памылка пры спраўджанні запампаванага файла",
    "Uploaded file is verified" : "Запампаваны файл спраўджаны",
    "Participants added successfully" : "Удзельнікі паспяхова дададзены",
    "Error while adding participants" : "Памылка пры дадаванні ўдзельнікаў",
    "Import a file" : "Імпартаваць файл",
    "Browse" : "Агляд",
    "Verifying uploaded file …" : "Спраўджанне запампаванага файла …",
    "This might take a moment" : "Гэта можа заняць крыху часу",
    "Send invitations" : "Адправіць запрашэнні",
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["Можна адправіць %n запрашэнне","Можна адправіць %n запрашэнні","Можна адправіць %n запрашэнняў","Можна адправіць %n запрашэнняў"],
    "Search participants or phone numbers" : "Пошук удзельнікаў або тэлефонных нумароў",
    "Creating the conversation …" : "Стварэнне размовы …",
    "Mark as read" : "Пазначыць як прачытанае",
    "Mark as unread" : "Пазначыць як непрачытанае",
    "Remove from favorites" : "Выдаліць з абранага",
    "Add to favorites" : "У абранае",
    "Unarchive conversation" : "Разархіваваць размову",
    "Ignore \"Do not disturb\"" : "Ігнараваць статус \"Не турбаваць\"",
    "You need to promote a new moderator before you can leave the conversation." : "Перш чым пакінуць размову, вам трэба павысіць статус новага мадэратара.",
    "New tag" : "Новы тэг",
    "Tag name" : "Назва тэга",
    "Conversation actions" : "Дзеянні з размовамі",
    "Tags" : "Тэгі",
    "Notify about calls" : "Апавяшчаць пра выклікі",
    "Hide message text" : "Схаваць тэкст паведамлення",
    "Remove all tags" : "Выдаліць усе тэгі",
    "Rename tag" : "Перайменаваць тэг",
    "Delete tag" : "Выдаліць тэг",
    "Move up" : "Перамясціць уверх",
    "Move down" : "Перамясціць уніз",
    "Pending invitations" : "Запрашэнні ў чаканні",
    "From {user} at {remoteServer}" : "Ад {user} на {remoteServer}",
    "Decline invitation" : "Адхіліць запрашэнне",
    "Accept invitation" : "Прыняць запрашэнне",
    "No pending invitations" : "Няма запрашэнняў у чаканні",
    "Home" : "Дадому",
    "Unread" : "Непрачытанае",
    "Mentions" : "Згадкі",
    "Meetings" : "Сустрэчы",
    "No matches found" : "Супадзенняў не знойдзена",
    "No conversations found" : "Размоў не знойдзена",
    "You have no archived conversations." : "Няма архіваваных размоў.",
    "Subscribe to an existing thread or start your own." : "Падпішыцеся на існуючую гутарку або пачніце сваю ўласную.",
    "You have no unread mentions." : "Няма непрачытаных згадак.",
    "You have no unread messages." : "Няма непрачытаных паведамленняў.",
    "An error occurred while performing the search" : "Падчас выканання пошуку адбылася памылка",
    "Conversation list" : "Спіс размоў",
    "Filter conversations by" : "Фільтраваць размовы па",
    "Unread messages" : "Непрачытаныя паведамленні",
    "Clear filters" : "Ачысціць фільтры",
    "New personal note" : "Новая асабістая нататка",
    "Back to conversations" : "Назад да размоў",
    "Threads" : "Гутаркі",
    "Archived conversations" : "Архіваваныя размовы",
    "Clear filter" : "Ачысціць фільтр",
    "Show more threads" : "Паказаць больш гутарак",
    "App settings" : "Налады праграмы",
    "Users" : "Карыстальнікі",
    "Groups" : "Групы",
    "Teams" : "Каманды",
    "Federated users" : "Федэратыўныя карыстальнікі",
    "New private conversation" : "Новая прыватная размова",
    "Other sources" : "Іншыя крыніцы",
    "Open conversations" : "Адкрытыя размовы",
    "No search results" : "Няма вынікаў пошуку",
    "Users, groups and teams" : "Карыстальнікі, групы і каманды",
    "Users and groups" : "Карыстальнікі і групы",
    "Users and teams" : "Карыстальнікі і каманды",
    "Groups and teams" : "Групы і каманды",
    "New group conversation" : "Новая групавая размова",
    "The meeting will start soon" : "Сустрэча неўзабаве пачнецца",
    "This meeting is scheduled for {startTime}" : "Гэта сустрэча запланавана на {startTime}",
    "You are currently waiting in the lobby" : "Вы зараз чакаеце ў лобі",
    "Advanced" : "Пашыраныя",
    "Select microphone" : "Выберыце мікрафон",
    "No microphone available" : "Няма даступных мікрафонаў",
    "Select speaker" : "Выберыце дынамік",
    "No speaker available" : "Няма даступных дынамікаў",
    "Select camera" : "Выберыце камеру",
    "No camera available" : "Няма даступных камер",
    "Select a device" : "Выберыце прыладу",
    "Playing …" : "Прайграванне …",
    "Test speakers" : "Тэст дынамікаў",
    "Test" : "Тэст",
    "Devices" : "Прылады",
    "Backgrounds" : "Фоны",
    "No audio" : "Няма гуку",
    "No camera" : "Няма камеры",
    "Display video as you will see it (mirrored)" : "Паказваць відэа так, як яго будзеце бачыць вы (адлюстраванае)",
    "Display video as others will see it" : "Паказваць відэа так, як яго будуць бачыць іншыя",
    "Calls are not supported in your browser" : "Ваш браўзер не падтрымлівае выклікі",
    "Access to microphone is only possible with HTTPS" : "Доступ да мікрафона магчымы толькі праз HTTPS",
    "Access to microphone was denied" : "Доступ да мікрафона забаронены",
    "Error while accessing microphone" : "Памылка доступу да мікрафона",
    "Access to camera is only possible with HTTPS" : "Доступ да камеры магчымы толькі праз HTTPS",
    "The call is being recorded." : "Выклік запісваецца.",
    "The call might be recorded." : "Выклік можа быць запісаны.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Запіс можа ўключаць ваш голас, відэа з камеры і абагулены экран. Перад далучэннем да выкліку патрабуецца ваша згода.",
    "Give consent to the recording of this call" : "Дайце згоду на запіс гэтага выкліку",
    "Show more info" : "Паказаць падрабязныя звесткі",
    "Audio is not available" : "Гук недаступны",
    "Video is not available" : "Відэа недаступна",
    "Start recording immediately with the call" : "Пачынаць запіс адразу з выклікам",
    "Notify all participants about this call" : "Апавясціць ўсіх удзельнікаў пра гэты выклік",
    "Apply settings" : "Прымяніць налады",
    "Error while uploading the file" : "Памылка пры запампоўванні файла",
    "Select a file" : "Выберыце файл",
    "Invalid path selected" : "Выбраны памылковы шлях",
    "Blur" : "Размытасць",
    "Upload" : "Запампаваць",
    "Files" : "Файлы",
    "(edited)" : "(адрэдагавана)",
    "The message has expired or has been deleted" : "Паведамленне пратэрмінавана або выдалена",
    "Cancel quote" : "Скасаваць цытату",
    "24 hours" : "24 гадзіны",
    "7 days" : "7 дзён",
    "30 days" : "30 дзён",
    "Until unpin" : "Пакуль не адмацуецца",
    "Clear reminder – {timeLocale}" : "Ачысціць напамін – {timeLocale}",
    "Edited by {actor}" : "Адрэдагаваў(-ла) {actor}",
    "Pinned by you" : "Замацавана вамі",
    "Pinned by {actor}" : "Замацаваў(-ла) {actor}",
    "Until {absoluteDate}" : "Да {absoluteDate}",
    "Message text copied to clipboard" : "Тэкст паведамлення скапіяваны ў буфер абмену",
    "Message text could not be copied" : "Не ўдалося скапіяваць тэкст паведамлення ",
    "Message forwarded to \"Note to self\"" : "Паведамленне пераслана ў \"Асабістыя нататкі\"",
    "Error while forwarding message to \"Note to self\"" : "Памылка пры перасыланні паведамлення ў \"Асабістыя нататкі\"",
    "A reminder was successfully removed" : "Напамін паспяхова выдалены",
    "Error occurred when removing a reminder" : "Пры выдаленні напаміну ўзнікла памылка",
    "A reminder was successfully set at {datetime}" : "Напамін паспяхова зададзены на {datetime}",
    "Error occurred when creating a reminder" : "Пры стварэнні напаміну ўзнікла памылка",
    "Add a reaction to this message" : "Дадаць рэакцыю на гэта паведамленне",
    "Reply" : "Адказаць",
    "More actions" : "Больш дзеянняў",
    "Set reminder" : "Задаць напамін",
    "Pin message" : "Замацаваць паведамленне",
    "Unpin message" : "Адмацаваць паведамленне",
    "Reply privately" : "Адказаць прыватна",
    "Edit message" : "Рэдагаваць паведамленне",
    "Copy message" : "Скапіяваць паведамленне",
    "Copy message link" : "Скапіяваць спасылку на паведамленне",
    "Go to file" : "Перайсці да файла",
    "Download file" : "Спампаваць файл",
    "Go to thread" : "Перайсці да гутаркі",
    "Edit thread details" : "Рэдагаваць звесткі пра гутарку",
    "Forward message" : "Пераслаць паведамленне",
    "Translate" : "Перакласці",
    "Set custom reminder" : "Задаць уласны напамін",
    "Keep pinned for" : "Замацоўваць на працягу",
    "Set custom period" : "Уласны перыяд",
    "Close reactions menu" : "Закрыць меню рэакцый",
    "React with {emoji}" : "Адрэагаваць з {emoji}",
    "React with another emoji" : "Адрэагаваць з дапамогай іншага эмодзі",
    "Choose a conversation to forward the selected message." : "Выберыце размову, у якую трэба пераслаць выбранае паведамленне.",
    "Error while forwarding message" : "Памылка падчас перасылкі паведамлення",
    "The message has been forwarded to {selectedConversationName}" : "Падемленне пераслана ў {selectedConversationName}",
    "Dismiss" : "Адхіліць",
    "Go to conversation" : "Перайсці да размовы",
    "Detect language" : "Вызначыць мову",
    "The message could not be translated" : "Не ўдалося перакласці паведамленне ",
    "Translation copied to clipboard" : "Пераклад скапіяваны ў буфер абмену",
    "Translation could not be copied" : "Не ўдалося скапіяваць пераклад",
    "Translate message" : "Перакласці паведамленне",
    "Source language to translate from" : "Зыходная мова для перакладу",
    "Translate from" : "Перакласці з",
    "Target language to translate into" : "Мэтавая мова для перакладу",
    "Translate to" : "Перакласці на",
    "Translating" : "Пераклад",
    "Copy translated text" : "Скапіяваць перакладзены тэкст",
    "Error when scheduling the message" : "Памылка пры планаванні паведамлення",
    "Reschedule" : "Запланаваць паўторна",
    "Send now" : "Адправіць зараз",
    "Choose a time" : "Выберыце час",
    "Send at custom time" : "Адправіць у зададзены час",
    "Will be sent without notification" : "Будзе адпраўлена без апавяшчэння",
    "Message read by everyone who shares their reading status" : "Паведамленне прачыталі ўсе, хто абагульвае статус прачытання",
    "Message sent" : "Паведамленне адпраўлена",
    "Sent without notification" : "Адпраўлена без апавяшчэння",
    "Deleting message" : "Выдаленне паведамлення",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Паведамленне паспяхова выдалена, але ёсць наладжаны бот або Matterbridge, і паведамленне, магчыма, ужо распаўсюджана ў іншыя сэрвісы",
    "Message deleted successfully" : "Паведамленне паспяхова выдалена",
    "Message could not be deleted because it is too old" : "Не ўдалося выдаліць паведамленне , бо яно занадта старое",
    "Only normal chat messages can be deleted" : "Можна выдаліць толькі звычайныя паведамленні чата",
    "An error occurred while deleting the message" : "Падчас выдалення паведамлення адбылася памылка",
    "Pinned" : "Замацавана",
    "Your browser does not support playing audio files" : "Ваш браўзер не падтрымлівае прайграванне аўдыяфайлаў",
    "Contact" : "Кантакт",
    "{stack} in {board}" : "{stack} у {board}",
    "Deck Card" : "Картка Deck",
    "Remove {fileName}" : "Выдаліць {fileName}",
    "Open this location in OpenStreetMap" : "Адкрыць гэта месца ў OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n адказ","%n адказы","%n адказаў","%n адказаў"],
    "Sending message" : "Адпраўка паведамлення",
    "Failed to send the message. Click to try again" : "Не ўдалося адправіць паведамленне. Націсніце, каб паспрабаваць яшчэ раз.",
    "Not enough free space to upload file" : "Недастаткова вольнай прасторы, каб запампаваць файл",
    "You cannot send messages to this conversation at the moment" : "У дадзены момант вы не можаце адпраўляць паведамленні ў гэту размову",
    "Could not update the message" : "Не атрымалася абнавіць паведамленне",
    "Reply to thread \"{threadTitle}\"" : "Адказаць у гутарцы \"{threadTitle}\"",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Чарнавік апытання • %n варыянты","Чарнавік апытання • %n варыянты","Чарнавік апытання • %n варыянтаў","Чарнавік апытання • %n варыянтаў"],
    "_%n vote_::_%n votes_" : ["%n голас","%n галасы","%n галасоў","%n галасоў"],
    "Edit poll draft" : "Рэдагаваць чарнавік апытання",
    "Delete poll draft" : "Выдаліць чарнавік апытання",
    "Open poll" : "Адкрыць апытанне",
    "See results" : "Паглядзець вынікі",
    "Reactions" : "Рэакцыі",
    "No permission to post reactions in this conversation" : "Няма дазволу на публікацыю рэакцый у гэтай размове",
    "and {participant}" : "і {participant}",
    "_and %n other participant_::_and %n other participants_" : ["і яшчэ %n удзельнік","і яшчэ %n удзельнікі","і яшчэ %n удзельнікаў","і яшчэ %n удзельнікаў"],
    "Show all reactions" : "Паказаць усе рэакцыі",
    "Add more reactions" : "Дадаць больш рэакцый",
    "Show or collapse system messages" : "Паказаць або згарнуць сістэмныя паведамленні",
    "No messages" : "Няма паведамленняў",
    "All messages have expired or have been deleted." : "Усе паведамленні пратэрмінаваны або выдалены.",
    "{author} (pinned by you)" : "{author} (замацавана вамі)",
    "{author} (pinned by {actor})" : "{author} (замацаваў(-ла) {actor})",
    "Unpin" : "Адмацаваць",
    "Cancel search" : "Скасаваць пошук",
    "Add a phone number" : "Дадаць нумар тэлефона",
    "Error: A password is required to create the conversation." : "Памылка: Для стварэння размовы патрабуецца пароль.",
    "All set, the conversation \"{conversationName}\" was created." : "Гатова, размова \"{conversationName}\" створана.",
    "Create a new group conversation" : "Стварыць новую групавую размову",
    "Add participants" : "Дадаць удзельнікаў",
    "Maximum length exceeded ({maxlength} characters)" : "Перавышана максімальная даўжыня ({maxlength} сімвалаў)",
    "Conversation visibility" : "Бачнасць размовы",
    "Allow guests to join via link" : "Дазволіць гасцям далучацца па спасылцы",
    "Enter password" : "Увядзіце пароль",
    "This conversation has been locked" : "Гэта размова была заблакіравана",
    "No permission to post messages in this conversation" : "Няма дазволу на публікацыю паведамленняў у гэтай размове",
    "Joining conversation …" : "Далучэнне да размовы …",
    "Write a message without notification" : "Напісаць паведамленне без апавяшчэння",
    "Create a thread silently" : "Пачаць гутарку бязгучна",
    "Create a thread" : "Стварыць гутарку",
    "Send message silently" : "Адправіць паведамленне бязгучна",
    "Send message" : "Адправіць паведамленне",
    "Send without notification" : "Адправіць без апавяшчэння",
    "The participant will not be notified about new messages" : "Удзельнік не будзе атрымліваць апавяшчэнняў аб новых паведамленнях",
    "Participants will not be notified about new messages" : "Удзельнікі не будуць атрымліваць апавяшчэнняў аб новых паведамленнях",
    "Message will be sent {datetimeString}" : "Паведамленне будзе адпраўлена {datetimeString}",
    "Thread title is required" : "Патрабуецца загаловак гутаркі",
    "Message text is required" : "Патрабуецца тэкст паведамлення",
    "The message could not be edited" : "Нне ўдалося адрэдагаваць паведамленне ",
    "File to share" : "Файл для абагульвання",
    "File upload is not available in this conversation" : "Запампоўванне файлаў недаступна ў гэтай размове",
    "Message was successfully scheduled" : "Паведамленне паспяхова запланавана",
    "Add emoji" : "Дадаць эмодзі",
    "Adding a mention will only notify users who did not read the message." : "Даданне згадкі прывядзе да апавяшчэння толькі тых карыстальнікаў, якія не прачыталі паведамленне.",
    "Thread title" : "Загаловак гутаркі",
    "Send later" : "Адправіць пазней",
    "Show scheduled messages" : "Паказаць запланаваныя паведамленні",
    "Cancel editing" : "Скасаваць рэдагаванне",
    "Schedule message" : "Запланаваць паведамленне",
    "{user} is out of office and might not respond." : "{user} не на працы і можа не адказаць.",
    "Absence period: {startDate} - {endDate}" : "Перыяд адсутнасці: {startDate} - {endDate}",
    "Replacement:" : "Замена:",
    "Share from {nextcloud}" : "Абагульванне з {nextcloud}",
    "Share from Files" : "Абагуліць з Файлаў",
    "Share files to the conversation" : "Абагуліць файлы ў размове",
    "Upload from device" : "Запампаваць з прылады",
    "Create new poll" : "Стварыць новае апытанне",
    "Smart picker" : "Smart picker",
    "Record voice message" : "Запісаць галасавое паведамленне",
    "End recording and send" : "Завяршыць запіс і адправіць",
    "Dismiss recording" : "Адхіліць запіс",
    "Access to the microphone was denied" : "Доступ да мікрафона забаронены",
    "Microphone either not available or disabled in settings" : "Мікрафон недаступны або адключаны ў наладах",
    "Error while recording audio" : "Памылка падчас запісу гуку",
    "New file" : "Новы файл",
    "Blank" : "Пусты",
    "Error while creating file" : "Памылка пры стварэнні файла",
    "Create and share a new file" : "Стварыце і абагульце новы файл",
    "Name of the new file" : "Назва новага файла",
    "Create file" : "Стварыць файл",
    "Someone is typing …" : "Хтосьці піша …",
    "{user1} is typing …" : "{user1} піша …",
    "{user1} and {user2} are typing …" : "{user1} і {user2} пішуць …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} і {user3} пішуць …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} і яшчэ %n пішуць …","{user1}, {user2}, {user3} і яшчэ %n пішуць …","{user1}, {user2}, {user3} і яшчэ %n пішуць …","{user1}, {user2}, {user3} і яшчэ %n пішуць …"],
    "Add more files" : "Дадаць больш файлаў",
    "Send" : "Адправіць",
    "In this conversation <strong>{user}</strong> can:" : "У гэтай размове <strong>{user}</strong> можа:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Рэдагаваць прадвызначаныя дазволы для ўдзельнікаў у <strong>{conversationName}</strong>",
    "Start a call" : "Пачаць выклік",
    "Skip the lobby" : "Прапусціць лобі",
    "Can post messages" : "Можа адпраўляць паведамленні",
    "Can post messages and reactions" : "Можа публікаваць паведамленні і рэакцыі",
    "Can add reactions" : "Можа дадаваць рэакцыі",
    "Enable the microphone" : "Уключыць мікрафон",
    "Enable the camera" : "Уключыць камеру",
    "Share the screen" : "Пачаць паказ экрана",
    "Update permissions" : "Абнавіць дазволы",
    "Updating permissions" : "Абнаўленне дазволаў",
    "No poll drafts" : "Няма чарнавікоў апытанняў",
    "There is no poll drafts yet saved for this conversation" : "Для гэтай размовы пакуль няма захаваных чарнавікоў апытанняў",
    "Create poll in {name}" : "Стварыць апытанне ў {name}",
    "Create poll" : "Стварыць апытанне",
    "Error while importing poll" : "Памылка пры імпарце апытання",
    "Question" : "Пытанне",
    "Ask a question" : "Задаць пытанне",
    "Import draft from file" : "Імпартаваць чарнавік з файла",
    "Answers" : "Адказы",
    "Answer {option}" : "Адказ {option}",
    "Delete poll option" : "Выдаліць варыянт апытання",
    "Add answer" : "Дадаць адказ",
    "Settings" : "Налады",
    "Anonymous poll" : "Ананімнае апытанне",
    "Multiple answers" : "Некалькі адказаў",
    "Save as draft" : "Захаваць як чарнавік",
    "Export draft to file" : "Экспартаваць чарнавік у файл",
    "You voted for this option" : "Вы прагаласавалі за гэты варыянт",
    "End poll" : "Завяршыць апытанне",
    "Change your vote" : "Змяніць  голас",
    "Results" : "Вынікі",
    "Voted participants" : "Удзельнікі, якія прагаласавалі",
    "Send a message to \"{roomName}\"" : "Адправіць паведамленне ў \"{roomName}\"",
    "Hide list of participants" : "Схаваць спіс удзельнікаў",
    "Show list of participants" : "Паказаць спіс удзельнікаў",
    "The message was sent to \"{roomName}\"" : "Паведамленне адпраўлена ў \"{roomName}\"",
    "Send message to room" : "Адправіць паведамленне ў пакой",
    "Back to main room" : "Вярнуцца ў галоўны пакой",
    "Back to your room" : "Вярнуцца ў свой пакой",
    "Message all rooms" : "Паведамленне ва ўсе пакоі",
    "Start session" : "Пачаць сеанс",
    "Start a call before you start a breakout room session" : "Пачніце выклік, перш чым пачаць сеанс групавых пакояў",
    "Stop session" : "Спыніць сеанс",
    "The message was sent to all breakout rooms" : "Паведамленне адпраўлена ва ўсе групавыя пакоі",
    "Send a message to all breakout rooms" : "Адправіць паведамленне ва ўсе групавыя пакоі",
    "Breakout rooms are not started" : "Групавыя пакоі не запушчаны",
    "Talk setup incomplete" : "Наладка Talk не завершана",
    "Disable lobby" : "Адключыць лобі",
    "Settings for participant \"{user}\"" : "Налады для ўдзельніка \"{user}\"",
    "Participant \"{user}\"" : "Удзельнік \"{user}\"",
    "moderator" : "мадэратар",
    "bot" : "бот",
    "guest" : "госць",
    "Ringing …" : "Выклік …",
    "Call rejected" : "Выклік адхілены",
    "Raised their hand" : "Падняў(-ла) руку",
    "Remove group and members" : "Выдаліць групу і ўдзельнікаў",
    "Remove team and members" : "Выдаліць каманду і членаў",
    "Remove participant" : "Выдаліць удзельніка",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Вы сапраўды хочаце выдаліць групу \"{displayName}\" і яе ўдзельнікаў з гэтай размовы?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Вы сапраўды хочаце выдаліць каманду \"{displayName}\" і яе членаў з гэтай размовы?",
    "Do you really want to remove {displayName} from this conversation?" : "Вы сапраўды хочаце выдаліць \"{displayName}\" з гэтай размовы?",
    "Notification was sent to {displayName}" : "Апавяшчэнне адпраўлена {displayName}",
    "Could not send notification to {displayName}" : "Не ўдалося адправіць апавяшчэнне {displayName}",
    "in the lobby" : "у лобі",
    "Move back to lobby" : "Вярнуцца ў лобі",
    "Move to conversation" : "Перайсці да размовы",
    "Demote from moderator" : "Пазбавіць правоў мадэратара",
    "Promote to moderator" : "Прызначыць мадэратарам",
    "Resend invitation" : "Адправіць запрашэнне паўторна",
    "Copy phone number" : "Скапіяваць нумар тэлефона",
    "Reset custom permissions" : "Скінуць карыстальніцкія дазволы",
    "Grant all permissions" : "Даць усе дазволы",
    "Remove all permissions" : "Выдаліць усе дазволы",
    "Internal note (reason to ban)" : "Унутраная заўвага (прычына блакіроўкі)",
    "Remove" : "Выдаліць",
    "Permissions modified for {displayName}" : "Зменены дазволы для {displayName}",
    "Add users, groups or teams" : "Дадаць карыстальнікаў, групы або каманды",
    "Add users or groups" : "Дадаць карыстальнікаў або групы",
    "Add users or teams" : "Дадаць карыстальнікаў або каманды",
    "Add users" : "Дадаць карыстальнікаў",
    "Add groups or teams" : "Дадаць групы або каманды",
    "Add groups" : "Дадаць групы",
    "Add teams" : "Дадаць каманды",
    "Add other sources" : "Дадаць іншыя крыніцы",
    "Add emails" : "Дадаць адрасы электроннай пошты",
    "Integrations" : "Інтэграцыі",
    "Add federated users" : "Дадаць федэратыўных карыстальнікаў",
    "Searching …" : "Пошук …",
    "Search for more users" : "Пошук іншых карыстальнікаў",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Вы можаце шукаць або дадаваць удзельнікаў па імені, электроннай пошце або ідэнтыфікатары ў федэратыўным воблаку.",
    "Search or add participants" : "Знайсці або дадаць удзельнікаў",
    "Invitation was sent to {actorId}" : "Запрашэнне адпраўлена {actorId}",
    "An error occurred while adding the participants" : "Падчас дадавання ўдзельнікаў узнікла памылка",
    "A new group conversation with selected participant will be created" : "Будзе створана новая групавая размова з выбраным удзельнікам",
    "Participants" : "Удзельнікі",
    "Pinned by a deleted user" : "Замацавана выдаленым карыстальнікам",
    "Participants ({count})" : "Удзельнікі ({count})",
    "Open chat" : "Адкрыць чат",
    "You have new unread messages in the chat." : "У вас ёсць новыя непрачытаныя паведамленні ў чаце.",
    "You have been mentioned in the chat." : "Вас згадалі ў чаце.",
    "Search messages" : "Пошук паведамленняў",
    "Chat" : "Чат",
    "Details" : "Падрабязнасці",
    "Shared items" : "Абагуленыя элементы",
    "Search in {name}" : "Пошук у {name}",
    "Threads in {name}" : "Гутаркі ў {name}",
    "{actor} in {conversation}" : "{actor} у {conversation}",
    "Search messages …" : "Пошук паведамленняў …",
    "Search options" : "Параметры пошуку",
    "From User" : "Ад карыстальніка",
    "Since" : "З",
    "Until" : "Да",
    "No results found" : "Вынікаў не знойдзена",
    "Load more results" : "Загрузіць больш вынікаў",
    "Recent threads" : "Нядаўнія гутаркі",
    "Projects" : "Праекты",
    "No shared items" : "Няма абагуленых элементаў",
    "Thread notifications" : "Апавяшчэнні гутаркі",
    "Thread actions" : "Дзеянні ў гутарцы",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Спасылка на размову",
    "No open conversations found" : "Адкрытых размоў не знойдзена",
    "Either there are no open conversations or you joined all of them." : "Або няма адкрытых размоў, або вы далучыліся да іх усіх.",
    "Search conversations or users" : "Пошук размоў або карыстальнікаў",
    "Select conversation" : "Выберыце размову",
    "Number length is not valid" : "Памылковая даўжыня нумара",
    "Region code is not valid" : "Памылковы код рэгіёна",
    "Number length is too short" : "Даўжыня нумара занадта кароткая",
    "Number length is too long" : "Даўжыня нумара занадта доўгая",
    "Number is not valid" : "Памылковы нумар",
    "Phone numbers" : "Нумары тэлефонаў",
    "Display name: {name}" : "Імя для паказу: {name}",
    "Edit display name" : "Рэдагаваць імя для паказу",
    "Display name (required)" : "Імя для паказу (абавязкова)",
    "Save name" : "Захаваць імя",
    "Error while setting personal setting" : "Памылка падчас захавання асабістых налад",
    "Error while saving sounds setting" : "Памылка пры захаванні налад гуку",
    "Compact conversations list" : "Кампактны спіс размоў",
    "Chat appearance" : "Выгляд чата",
    "Messages list" : "Спіс паведамленняў",
    "Play sounds when participants join or leave a call" : "Прайграваць гукі, калі ўдзельнікі далучаюцца да выкліку або пакідаюць яго",
    "Notification settings" : "Налады апавяшчэнняў",
    "Default language" : "Прадвызначаная мова",
    "Default language ({languageName})" : "Прадвызначаная мова ({languageName})",
    "Select location for attachments" : "Выберыце размяшчэнне далучэнняў",
    "Error while setting attachment folder" : "Памылка пры заданні папкі для далучэнняў",
    "Turn camera and microphone off by default" : "Прадвызначана выключаць камеру і мікрафон",
    "Blur camera background by default" : "Прадвызначана размываць фон камеры",
    "Appearance & Sounds" : "Знешні выгляд і гукі",
    "Privacy" : "Прыватнасць",
    "Attachments folder" : "Папка для далучэнняў",
    "Search" : "Пошук",
    "Edit your last message" : "Рэдагаваць апошняе паведамленне",
    "Shortcuts while in a call" : "Спалучэнні клавіш падчас выкліку",
    "Camera on and off" : "Уключыць/выключыць камеру",
    "Microphone on and off" : "Уключыць/выключыць мікрафон",
    "Raise or lower hand" : "Падняць або апусціць руку",
    "Zoom-in / zoom-out a screen share" : "Павялічыць/паменшыць маштаб паказу экрана",
    "Mouse wheel" : "Кола мышы",
    "Start call silently" : "Пачаць бязгучны выклік",
    "Start call" : "Пачаць выклік",
    "End call" : "Завяршыць выклік",
    "This call has just ended" : "Гэты выклік толькі што завяршыўся.",
    "You will be able to join the call only after a moderator starts it." : "Вы зможаце далучыцца да выкліку толькі пасля таго, як яе пачне мадэратар.",
    "End call for everyone" : "Завяршыць выклік для ўсіх",
    "Starting the recording" : "Пачатак запісу",
    "Recording" : "Запіс",
    "The call has been running for one hour." : "Выклік доўжыцца ўжо гадзіну",
    "Cancel recording start" : "Скасаваць пачатак запісу",
    "Stop recording" : "Спыніць запіс",
    "Raise hand" : "Падняць руку",
    "Raise hand (R)" : "Падняць руку (R)",
    "Lower hand" : "Апусціць руку",
    "Lower hand (R)" : "Апусціць руку (R)",
    "Send a reaction" : "Адправіць рэакцыю",
    "React with {reaction}" : "Адрэагаваць з {reaction}",
    "All tasks done!" : "Усе заданні выкананы!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} з %n задання","{done} з %n заданняў","{done} з %n заданняў","{done} з %n заданняў"],
    "_%n participant in call_::_%n participants in call_" : ["У выкліку %n удзельнік","У выкліку %n удзельнікі","У выкліку %n удзельнікаў","У выкліку %n удзельнікаў"],
    "Scheduled messages" : "Запланаваныя паведамленні",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не бачыць ваш экран. Каб палепшыць сітуацыю, паспрабуйце адключыць відэа або размытасць фону падчас паказу экрана.",
    "Disable background blur" : "Адключыць размытасць фону",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не бачыць ваш экран. Каб палепшыць сітуацыю, паспрабуйце адключыць відэа падчас паказу экрана.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не бачыць ваш экран.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не бачыць вас.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не разумець вас і не бачыць ваш экран. Каб палепшыць сітуацыю, паспрабуйце адключыць відэа або размытасць фону падчас паказу экрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не разумець вас і не бачыць ваш экран. Каб палепшыць сітуацыю, паспрабуйце адключыць відэа падчас паказу экрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не разумець вас і не бачыць ваш экран. Каб палепшыць сітуацыю, паспрабуйце адключыць паказ экрана.",
    "Disable screenshare" : "Адключыць паказ экрана",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не разумець вас і не бачыць ваш экран. Каб палепшыць сітуацыю, паспрабуйце адключыць размытасць фону відэа.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не разумець і не бачыць вас. Каб палепшыць сітуацыю, паспрабуйце адключыць відэа.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ваша інтэрнэт-злучэнне або камп'ютар перагружаны, і іншыя ўдзельнікі могуць не разумець вас.",
    "Mute others" : "Адключыць гук іншых",
    "Start recording" : "Пачаць запіс",
    "Set up breakout rooms" : "Наладзіць групавыя пакоі",
    "Open Calendar" : "Адкрыць Каляндар",
    "Remove participant {name}" : "Выдаліць удзельніка {name}",
    "Would you like to delete this conversation?" : "Вы хочаце выдаліць гэтую размову?",
    "Are you sure you want to delete this conversation?" : "Вы ўпэўнены, што хочаце выдаліць гэту размову?",
    "Delete now" : "Выдаліць зараз",
    "Keep" : "Пакінуць",
    "Select a region" : "Выберыце рэгіён",
    "Local time: {time}" : "Мясцовы час: {time}",
    "Scheduled {datetime}" : "Запланавана {datetime}",
    "Scheduled for {datetime}" : "Запланавана на {datetime}",
    "Search …" : "Пошук ...",
    "Message without mention" : "Паведамленне без згадкі",
    "Mention myself" : "Згадаць сябе",
    "Mention everyone" : "Згадаць ўсіх",
    "Select a conversation" : "Выберыце размову",
    "Select a mode" : "Выберыце рэжым",
    "You do not have permissions to access this conversation." : "У вас няма дазволу на доступ да гэтай размовы.",
    "Join a different conversation or start a new one." : "Далучайцеся да іншай размовы або пачніце новую.",
    "The conversation does not exist" : "Размова не існуе",
    "Join a conversation or start a new one!" : "Далучайцеся да размовы або пачніце новую!",
    "Creating and joining a conversation with \"{userid}\"" : "Стварэнне і далучэнне да размовы з карыстальнікам \"{userid}\"",
    "Join a conversation or start a new one" : "Далучайцеся да размовы або пачніце новую",
    "Error while joining the conversation" : "Памылка пры далучэнні да размовы",
    "Another user" : "Іншы карыстальнік",
    "Nextcloud URL" : "URL-адрас NextCloud",
    "Nextcloud user" : "Карыстальнік Nextcloud",
    "User password" : "Пароль карыстальніка",
    "Talk conversation" : "Размова Talk",
    "Skip TLS verification" : "Прапусціць праверку TLS",
    "Matrix server URL" : "URL-адрас сервера Matrix",
    "User" : "Карыстальнік",
    "Matrix channel" : "Канал Matrix",
    "Mattermost server URL" : "URL-адрас сервера Mattermost",
    "Mattermost user" : "Карыстальнік Mattermost",
    "Team name" : "Назва каманды",
    "Channel name" : "Назва канала",
    "Rocket.Chat server URL" : "URL-адрас сервера Rocket.Chat",
    "User name or email address" : "Імя карыстальніка або электронная пошта",
    "Rocket.Chat channel" : "Канал Rocket.Chat",
    "Zulip server URL" : "URL-адрас сервера Zulip",
    "Bot user name" : "Імя карыстальніка бота",
    "Bot API key" : "Ключ API бота",
    "Zulip channel" : "Канал Zulip",
    "API token" : "Токен API",
    "Slack channel" : "Канал Slack",
    "Server ID or name" : "Ідэнтыфікатар або назва сервера",
    "Channel ID (prefixed with \"ID:\") or name" : "Ідэнтыфікатар (з прэфіксам \"ID:\") або назва канала",
    "Channel" : "Канал",
    "Login" : "Лагін",
    "Chat ID" : "Ідэнтыфікатар чата",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL-адрас IRC-сервера (напрыклад, chat.freenode.net:6667)",
    "Nickname" : "Псеўданім",
    "IRC channel" : "Канал IRC",
    "Channel password" : "Пароль канала",
    "NickServ nickname" : "Псеўданім NickServ",
    "NickServ password" : "Пароль NickServ",
    "Use TLS" : "Выкарыстоўваць TLS",
    "Use SASL" : "Выкарыстоўваць SASL",
    "Client ID" : "Ідэнтыфікатар кліента",
    "Team ID" : "Ідэнтыфікатар каманды",
    "Thread ID" : "Ідэнтыфікатар гутаркі",
    "XMPP/Jabber server URL" : "URL-адрас сервера XMPP/Jabber",
    "MUC server URL" : "URL-адрас сервера MUC",
    "Pinned messages" : "Замацаваныя паведамленні",
    "Media" : "Медыя",
    "Polls" : "Апытанні",
    "Deck cards" : "Карткі Deck",
    "Voice messages" : "Галасавыя паведамленні",
    "Locations" : "Месцазнаходжанні",
    "Call recordings" : "Запісы выклікаў",
    "Audio" : "Аўдыя",
    "Show all pinned messages" : "Паказаць усе замацаваныя паведамленні",
    "Show all media" : "Паказаць усе медыя",
    "Show all files" : "Паказаць усе файлы",
    "Show all polls" : "Паказаць усе апытанні",
    "Show all deck cards" : "Паказаць усе карткі Deck",
    "Show all voice messages" : "Паказаць усе галасавыя паведамленні",
    "Show all locations" : "Паказаць усе месцазнаходжанні",
    "Show all call recordings" : "Паказаць усе запісы выклікаў",
    "Show all audio" : "Паказаць усе аўдыя",
    "Show all other" : "Паказаць усе іншыя",
    "Follow conversation settings" : "Прытрымлівацца налад размовы",
    "Group" : "Група",
    "Team" : "Каманда",
    "You reconnected to the call" : "Вы зноў падключыліся да выкліку",
    "{actor} reconnected to the call" : "{actor} зноў падключыўся(-лася) да выкліку",
    "You added {user0} and {user1}" : "Вы дадалі {user0} і {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Вы дадалі {user0}, {user1} і яшчэ %n удзельніка","Вы дадалі {user0}, {user1} і яшчэ %n удзельнікаў","Вы дадалі {user0}, {user1} і яшчэ %n удзельнікаў","Вы дадалі {user0}, {user1} і яшчэ %n удзельнікаў"],
    "An administrator added you and {user0}" : "Адміністратар дадаў вас і {user0}",
    "{actor} added you and {user0}" : "{actor} дадаў(-ла) вас і {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Адміністратар дадаў вас, {user0} і яшчэ %n удзельніка","Адміністратар дадаў вас, {user0} і яшчэ %n удзельнікаў","Адміністратар дадаў вас, {user0} і яшчэ %n удзельнікаў","Адміністратар дадаў вас, {user0} і яшчэ %n удзельнікаў"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} дадаў(-ла) вас, {user0} і яшчэ %n удзельніка","{actor} дадаў(-ла) вас, {user0} і яшчэ %n удзельнікаў","{actor} дадаў(-ла) вас, {user0} і яшчэ %n удзельнікаў","{actor} дадаў(-ла) вас, {user0} і яшчэ %n удзельнікаў"],
    "An administrator added {user0} and {user1}" : "Адміністратар дадаў {user0} і {user1}",
    "{actor} added {user0} and {user1}" : "{actor} дадаў(-ла) {user0} і {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Адміністратар дадаў {user0}, {user1} і яшчэ %n удзельніка","Адміністратар дадаў {user0}, {user1} і яшчэ %n удзельнікаў","Адміністратар дадаў {user0}, {user1} і яшчэ %n удзельнікаў","Адміністратар дадаў {user0}, {user1} і яшчэ %n удзельнікаў"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} дадаў(-ла) {user0}, {user1} і яшчэ %n удзельніка","{actor} дадаў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў","{actor} дадаў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў","{actor} дадаў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў"],
    "You removed {user0} and {user1}" : "Вы выдалілі {user0} і {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Вы выдалілі {user0}, {user1} і яшчэ %n удзельніка","Вы выдалілі {user0}, {user1} і яшчэ %n удзельнікаў","Вы выдалілі {user0}, {user1} і яшчэ %n удзельнікаў","Вы выдалілі {user0}, {user1} і яшчэ %n удзельнікаў"],
    "An administrator removed you and {user0}" : "Адміністратар выдаліў вас і {user0}",
    "{actor} removed you and {user0}" : "{actor} выдаліў(-ла) вас і {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Адміністратар выдаліў вас, {user0} і яшчэ %n удзельніка","Адміністратар выдаліў вас, {user0} і яшчэ %n удзельнікаў","Адміністратар выдаліў вас, {user0} і яшчэ %n удзельнікаў","Адміністратар выдаліў вас, {user0} і яшчэ %n удзельнікаў"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} выдаліў(-ла) вас, {user0} і яшчэ %n удзельніка","{actor} выдаліў(-ла) вас, {user0} і яшчэ %n удзельнікаў","{actor} выдаліў(-ла) вас, {user0} і яшчэ %n удзельнікаў","{actor} выдаліў(-ла) вас, {user0} і яшчэ %n удзельнікаў"],
    "An administrator removed {user0} and {user1}" : "Адміністратар выдаліў {user0} і {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} выдаліў(-ла) {user0} і {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Адміністратар выдаліў {user0}, {user1} і яшчэ %n удзельніка","Адміністратар выдаліў {user0}, {user1} і яшчэ %n удзельнікаў","Адміністратар выдаліў {user0}, {user1} і яшчэ %n удзельнікаў","Адміністратар выдаліў {user0}, {user1} і яшчэ %n удзельнікаў"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} выдаліў(-ла) {user0}, {user1} і яшчэ %n удзельніка","{actor} выдаліў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў","{actor} выдаліў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў","{actor} выдаліў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў"],
    "You and {user0} joined the call" : "Вы і {user0} далучыліся да выкліку",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Вы, {user0} і яшчэ %n удзельнік далучыліся да выкліку","Вы, {user0} і яшчэ %n удзельнікі далучыліся да выкліку","Вы, {user0} і яшчэ %n удзельнікаў далучыліся да выкліку","Вы, {user0} і яшчэ %n удзельнікаў далучыліся да выкліку"],
    "{user0} and {user1} joined the call" : "{user0} і {user1} далучыліся да выкліку",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} і яшчэ %n удзельнік далучыліся да выкліку","{user0}, {user1} і яшчэ %n удзельнікі далучыліся да выкліку","{user0}, {user1} і яшчэ %n удзельнікаў далучыліся да выкліку","{user0}, {user1} і яшчэ %n удзельнікаў далучыліся да выкліку"],
    "You and {user0} left the call" : "Вы і {user0} выйшлі з выкліку",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Вы, {user0} і яшчэ %n удзельнік выйшлі з выкліку","Вы, {user0} і яшчэ %n удзельнікі выйшлі з выкліку","Вы, {user0} і яшчэ %n удзельнікаў выйшлі з выкліку","Вы, {user0} і яшчэ %n удзельнікаў выйшлі з выкліку"],
    "{user0} and {user1} left the call" : "{user0} і {user1} выйшлі з выкліку",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} і яшчэ %n удзельнік выйшлі з выкліку","{user0}, {user1} і яшчэ %n удзельнікі выйшлі з выкліку","{user0}, {user1} і яшчэ %n удзельнікаў выйшлі з выкліку","{user0}, {user1} і яшчэ %n удзельнікаў выйшлі з выкліку"],
    "You promoted {user0} and {user1} to moderators" : "Вы прызначылі {user0} і {user1} мадэратарамі",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Вы прызначылі {user0}, {user1} і яшчэ %n удзельніка мадэратарамі","Вы прызначылі {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі","Вы прызначылі {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі","Вы прызначылі {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі"],
    "An administrator promoted you and {user0} to moderators" : "Адміністратар прызначыў вас і {user0} мадэратарамі",
    "{actor} promoted you and {user0} to moderators" : "{actor} прызначыў(-ла) вас і {user0} мадэратарамі",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Адміністратар прызначыў вас, {user0} і яшчэ %n удзельніка мадэратарамі","Адміністратар прызначыў вас, {user0} і яшчэ %n удзельнікаў мадэратарамі","Адміністратар прызначыў вас, {user0} і яшчэ %n удзельнікаў мадэратарамі","Адміністратар прызначыў вас, {user0} і яшчэ %n удзельнікаў мадэратарамі"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} прызначыў(-ла) вас, {user0} і яшчэ %n удзельніка мадэратарамі","{actor} прызначыў(-ла) вас, {user0} і яшчэ %n удзельнікаў мадэратарамі","{actor} прызначыў(-ла) вас, {user0} і яшчэ %n удзельнікаў мадэратарамі","{actor} прызначыў(-ла) вас, {user0} і яшчэ %n удзельнікаў мадэратарамі"],
    "An administrator promoted {user0} and {user1} to moderators" : "Адміністратар прызначыў {user0} і {user1} мадэратарамі",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} прызначыў(-ла) {user0} і {user1} мадэратарамі",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Адміністратар прызначыў {user0}, {user1} і яшчэ %n удзельніка мадэратарамі","Адміністратар прызначыў {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі","Адміністратар прызначыў {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі","Адміністратар прызначыў {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} прызначыў(-ла) {user0}, {user1} і яшчэ %n удзельніка мадэратарамі","{actor} прызначыў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі","{actor} прызначыў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі","{actor} прызначыў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў мадэратарамі"],
    "You demoted {user0} and {user1} from moderators" : "Вы пазбавілі {user0} і {user1} правоў мадэратара",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Вы пазбавілі {user0}, {user1} і яшчэ %n удзельніка правоў мадэратара","Вы пазбавілі {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара","Вы пазбавілі {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара","Вы пазбавілі {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара"],
    "An administrator demoted you and {user0} from moderators" : "Адміністратар пазбавіў вас і {user0} правоў мадэратара",
    "{actor} demoted you and {user0} from moderators" : "{actor} пазбавіў(-ла) вас і {user0} правоў мадэратара",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Адміністратар пазбавіў вас, {user0} і яшчэ %n удзельніка правоў мадэратара","Адміністратар пазбавіў вас, {user0} і яшчэ %n удзельнікаў правоў мадэратара","Адміністратар пазбавіў вас, {user0} і яшчэ %n удзельнікаў правоў мадэратара","Адміністратар пазбавіў вас, {user0} і яшчэ %n удзельнікаў правоў мадэратара"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} пазбавіў(-ла) вас, {user0} і яшчэ %n удзельніка правоў мадэратара","{actor} пазбавіў(-ла) вас, {user0} і яшчэ %n удзельнікаў правоў мадэратара","{actor} пазбавіў(-ла) вас, {user0} і яшчэ %n удзельнікаў правоў мадэратара","{actor} пазбавіў(-ла) вас, {user0} і яшчэ %n удзельнікаў правоў мадэратара"],
    "An administrator demoted {user0} and {user1} from moderators" : "Адміністратар пазбавіў {user0} і {user1} правоў мадэратара",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} пазбавіў(-ла) {user0} і {user1} правоў мадэратара",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Адміністратар пазбавіў {user0}, {user1} і яшчэ %n удзельніка правоў мадэратара","Адміністратар пазбавіў {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара","Адміністратар пазбавіў {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара","Адміністратар пазбавіў {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} пазбавіў(-ла) {user0}, {user1} і яшчэ %n удзельніка правоў мадэратара","{actor} пазбавіў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара","{actor} пазбавіў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара","{actor} пазбавіў(-ла) {user0}, {user1} і яшчэ %n удзельнікаў правоў мадэратара"],
    "You:" : "Вы:",
    "You: {lastMessage}" : "Вы: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(адрэдагавана вамі)",
    "(edited by a deleted user)" : "(адрэдагавана выдаленым карыстальнікам)",
    "(edited by {moderator})" : "(адрэдагаваў(-ла) {moderator})",
    "The recording failed. Please contact your administrator." : "Не ўдалося зрабіць запіс. Звярніцеся да адміністратара.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Вы спрабуеце далучыцца да размовы, маючы актыўны сеанс у іншым акне або на іншай прыладзе. Nextcloud Talk пакуль што не падтрымлівае такі сцэнарый. Што вы хочаце зрабіць?",
    "Leave this page" : "Выйсці з гэтай старонкі",
    "Join here" : "Далучыцца тут",
    "Deck card has been posted to {conversation}" : "Картка Deck была апублікавана ў  {conversation}",
    "An error occurred while posting deck card to conversation" : "Падчас публікацыі карткі Deck у размове адбылася памылка",
    "Post to a conversation" : "Апублікаваць у размове",
    "Post to conversation" : "Апублікаваць у размове",
    "Location has been posted to {conversation}" : "Месцазнаходжанне апублікавана ў {conversation}",
    "An error occurred while posting location to conversation" : "Падчас публікацыі месцазнаходжання ў размове адбылася памылка",
    "Share to a conversation" : "Абагуліць у размове",
    "Share to conversation" : "Абагуліць у размове",
    "In conversation" : "У размове",
    "Search in conversation: {conversation}" : "Пошук у размове: {conversation}",
    "Error while clearing conversation history" : "Памылка пры ачыстцы гісторыі размовы",
    "Conversation password has been saved" : "Пароль размовы захаваны",
    "Conversation password has been removed" : "Пароль размовы выдалены",
    "Error occurred while saving conversation password" : "Памылка пры захаванні пароля размовы",
    "Conversation picture set" : "Аватар размовы зададзены",
    "Conversation picture deleted" : "Аватар размовы выдалены",
    "Could not delete the conversation picture" : "Не ўдалося выдаліць аватар размовы",
    "Could not post message: {errorMessage}" : "Не ўдалося апублікаваць паведамленне: {errorMessage}",
    "Participant is banned successfully" : "Удзельнік паспяхова заблакіраваны",
    "Error while banning the participant" : "Памылка пры блакіраванні ўдзельніка",
    "Could not send invitation to {actorId}" : "Не ўдалося адправіць запрашэнне {actorId}",
    "Invitations sent" : "Запрашэнні адпраўлены",
    "Error occurred when sending invitations" : "Падчас адпраўкі запрашэнняў узнікла памылка",
    "Failed to join the conversation." : "Не атрымалася далучыцца да размовы.",
    "An error occurred while creating breakout rooms" : "Пры стварэнні групавых пакояў адбылася памылка",
    "An error occurred while deleting breakout rooms" : "Пры выдаленні групавых пакояў адбылася памылка",
    "An error occurred while starting breakout rooms" : "Пры запуску групавых пакояў адбылася памылка",
    "An error occurred while stopping breakout rooms" : "Пры спыненні групавых пакояў адбылася памылка",
    "An error occurred while sending a message to the breakout rooms" : "Пры адпраўцы паведамлення ў групавыя пакоі адбылася памылка",
    "An error occurred while joining breakout room" : "Пры далучэнні да групавога пакоя адбылася памылка",
    "Failed to rename the thread" : "Не ўдалося перайменаваць гутарку",
    "An error occurred while accepting an invitation" : "Падчас прыняцця запрашэння адбылася памылка",
    "An error occurred while rejecting an invitation" : "Падчас адхілення запрашэння адбылася памылка",
    "{guest} (guest)" : "{guest} (госць)",
    "Poll draft has been saved" : "Чарнавік апытання захаваны",
    "An error occurred while saving the draft" : "Падчас захавання чарнавіка ўзнікла памылка",
    "An error occurred while submitting your vote" : "Падчас адпраўкі голаса ўзнікла памылка",
    "An error occurred while ending the poll" : "Падчас заканчэння апытання ўзнікла памылка",
    "An error occurred while deleting the poll draft" : "Падчас выдалення чарнавіка апытання ўзнікла памылка",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Апытанне \"{name}\" створана карыстальнікам {user}. Націсніце, каб прагаласаваць",
    "Failed to add reaction" : "Не ўдалося дадаць рэакцыю",
    "Failed to remove reaction" : "Не ўдалося выдаліць рэакцыю",
    "Error while uploading file \"{fileName}\"" : "Памылка пры запампоўванні файла \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Недастаткова вольнай прасторы, каб запампаваць файл \"{fileName}\"",
    "You are not allowed to share files" : "Вам не дазволена абагульваць файлы",
    "Error while sharing file" : "Памылка пры абагульванні файла",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Ваш браўзер не цалкам падтрымліваецца Nextcloud Talk. Выкарыстоўвайце апошнюю версію Mozilla Firefox, Microsoft Edge, Google Chrome, Opera або Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n гадзіна","%n гадзіны","%n гадзін","%n гадзін"],
    "_%n day_::_%n days_" : ["%n дзень","%n дні","%n дзён","%n дзён"],
    "_%n week_::_%n weeks_" : ["%n тыдзень","%n тыдні","%n тыдняў","%n тыдняў"],
    "_In %n hour_::_In %n hours_" : ["Праз %n гадзіну","Праз %n гадзіны","Праз %n гадзін","Праз %n гадзін"],
    "_%n minute _::_%n minutes_" : ["%n хвіліна","%n хвіліны","%n хвілін","%n хвілін"],
    "In {hours} and {minutes}" : "Праз {hours} і {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Праз %n хвіліну","Праз %n хвіліны","Праз %n хвілін","Праз %n хвілін"],
    "Later today – {timeLocale}" : "Пазней сёння – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Заўтра – {timeLocale}",
    "This weekend – {timeLocale}" : "У гэты ўік-энд – {timeLocale}",
    "Next week – {timeLocale}" : "На наступным тыдні – {timeLocale}",
    "Message link copied to clipboard" : "Спасылка на паведамленне скапіявана ў буфер абмену",
    "Conversation link copied to clipboard" : "Спасылка на размову скапіявана ў буфер абмену",
    "The link could not be copied" : "Не ўдалося скапіяваць спасылку ",
    "Failed to connect. Retrying …" : "Не атрымалася злучыцца. Паўторная спроба…",
    "Please restart the app." : "Перазапусціце праграму.",
    "Please reload the page." : "Перазагрузіце старонку.",
    "Please try to restart the app." : "Паспрабуйце перазапусціць праграму.",
    "Please try to reload the page." : "Паспрабуйце перазагрузіць старонку.",
    "Do not disturb" : "Не турбаваць",
    "Away" : "Адышоў",
    "Microphone {number}" : "Мікрафон {number}",
    "Camera {number}" : "Камера {number}",
    "Speaker {number}" : "Дынамік {number}",
    "Access to microphone & camera was denied" : "Доступ да мікрафона і камеры забаронены",
    "WebRTC is not supported in your browser" : "WebRTC не падтрымліваецца вашым браўзерам",
    "Please use a different browser like Firefox or Chrome" : "Выкарыстоўвайце іншы браўзер, напрыклад, Firefox або Chrome",
    "Error while accessing microphone & camera" : "Памылка доступу да мікрафона і камеры",
    "Join conversations at any time, anywhere, on any device." : "Далучайцеся да размоў у любы час, у любым месцы і на любой прыладзе.",
    "Android app" : "Праграма для Android",
    "iOS app" : "Праграма для iOS",
    "__language_name__" : "Беларуская",
    "Tasks" : "Заданні",
    "Notes" : "Нататкі",
    "Reports" : "Справаздачы",
    "Decisions" : "Рашэнні",
    "Next meeting" : "Наступная сустрэча",
    "Join conversations from remote Nextcloud servers" : "Далучайцеся да размоў з аддаленых сервераў Nextcloud",
    "Set reminder for later today" : "Задаць напамін на пазней сёння",
    "Set reminder for tomorrow" : "Задаць напамін на заўтра",
    "Set reminder for this weekend" : "Задаць напамін на гэты ўік-энд",
    "Set reminder for next week" : "Задаць напамін на наступны тыдзень",
    "Open poll • You voted already" : "Адкрытае апытанне • Вы ўжо прагаласавалі",
    "Open poll • Click to vote" : "Адкрытае апытанне • Націсніце, каб прагаласаваць",
    "Poll • Ended" : "Апытанне • Завершана",
    "Talk recording from {time} ({conversation})" : "Галасавое паведамленне ад {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Вынікі апытання • %n голас","Вынікі апытання • %n галасы","Вынікі апытання • %n галасоў","Вынікі апытання • %n галасоў"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Адкрыць апытанне • %n голас","Адкрыць апытанне • %n галасы","Адкрыць апытанне • %n галасоў","Адкрыць апытанне • %n галасоў"],
    "Submit vote" : "Адправіць голас",
    "Your privacy setting has been saved" : "Вашы налады прыватнасці захаваны",
    "Your personal setting has been saved" : "Вашы асабістыя налады захаваны",
    "Failed to save sounds setting" : "Не атрымалася захаваць налады гуку",
    "Sounds setting saved" : "Налады гуку захаваны",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk абноўлена, вы не можаце пачаць або далучыцца да выкліку.",
    "Nextcloud Talk was updated." : "Nextcloud Talk была абноўлена.",
    "Nextcloud is in maintenance mode." : "Nextcloud знаходзіцца ў рэжыме тэхнічнага абслугоўвання."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
